@@ -8,8 +8,8 @@
  */
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_ccopy( const CBLAS_INDEX N, const void *X,
-                      const CBLAS_INDEX incX, void *Y, const CBLAS_INDEX incY)
+void API_SUFFIX(cblas_ccopy)( const CBLAS_INT N, const void *X,
+                      const CBLAS_INT incX, void *Y, const CBLAS_INT incY)
 {
 #ifdef F77_INT
    F77_INT F77_N=N, F77_incX=incX, F77_incY=incY;
