@@ -9,11 +9,11 @@
 
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
+void API_SUFFIX(cblas_dtrsm)(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
                  const CBLAS_UPLO Uplo, const CBLAS_TRANSPOSE TransA,
-                 const CBLAS_DIAG Diag, const CBLAS_INDEX M, const CBLAS_INDEX N,
-                 const double alpha, const double  *A, const CBLAS_INDEX lda,
-                 double  *B, const CBLAS_INDEX ldb)
+                 const CBLAS_DIAG Diag, const CBLAS_INT M, const CBLAS_INT N,
+                 const double alpha, const double  *A, const CBLAS_INT lda,
+                 double  *B, const CBLAS_INT ldb)
 
 {
    char UL, TA, SD, DI;
@@ -46,7 +46,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Side == CblasLeft ) SD='L';
       else
       {
-         cblas_xerbla(2, "cblas_dtrsm","Illegal Side setting, %d\n", Side);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_dtrsm","Illegal Side setting, %d\n", Side);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -55,7 +55,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Uplo == CblasLower) UL='L';
       else
       {
-         cblas_xerbla(3, "cblas_dtrsm","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_dtrsm","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -66,7 +66,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( TransA == CblasNoTrans  ) TA='N';
       else
       {
-         cblas_xerbla(4, "cblas_dtrsm","Illegal Trans setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_dtrsm","Illegal Trans setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -76,7 +76,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Diag == CblasNonUnit) DI='N';
       else
       {
-         cblas_xerbla(5, "cblas_dtrsm","Illegal Diag setting, %d\n", Diag);
+         API_SUFFIX(cblas_xerbla)(5, "cblas_dtrsm","Illegal Diag setting, %d\n", Diag);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -99,7 +99,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Side == CblasLeft ) SD='R';
       else
       {
-         cblas_xerbla(2, "cblas_dtrsm","Illegal Side setting, %d\n", Side);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_dtrsm","Illegal Side setting, %d\n", Side);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -109,7 +109,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Uplo == CblasLower) UL='U';
       else
       {
-         cblas_xerbla(3, "cblas_dtrsm","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_dtrsm","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -120,7 +120,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( TransA == CblasNoTrans  ) TA='N';
       else
       {
-         cblas_xerbla(4, "cblas_dtrsm","Illegal Trans setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_dtrsm","Illegal Trans setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -130,7 +130,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       else if ( Diag == CblasNonUnit) DI='N';
       else
       {
-         cblas_xerbla(5, "cblas_dtrsm","Illegal Diag setting, %d\n", Diag);
+         API_SUFFIX(cblas_xerbla)(5, "cblas_dtrsm","Illegal Diag setting, %d\n", Diag);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -146,7 +146,7 @@ void cblas_dtrsm(const CBLAS_LAYOUT layout, const CBLAS_SIDE Side,
       F77_dtrsm(F77_SD, F77_UL, F77_TA, F77_DI, &F77_N, &F77_M, &alpha, A,
                &F77_lda, B, &F77_ldb);
    }
-   else cblas_xerbla(1, "cblas_dtrsm","Illegal layout setting, %d\n", layout);
+   else API_SUFFIX(cblas_xerbla)(1, "cblas_dtrsm","Illegal layout setting, %d\n", layout);
    CBLAS_CallFromC = 0;
    RowMajorStrg = 0;
    return;
