@@ -7,7 +7,7 @@
  */
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
+void API_SUFFIX(cblas_stbsv)(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
                  const CBLAS_TRANSPOSE TransA, const CBLAS_DIAG Diag,
                  const CBLAS_INT N, const CBLAS_INT K, const float  *A, const CBLAS_INT lda,
                  float  *X, const CBLAS_INT incX)
@@ -41,7 +41,7 @@ void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Uplo == CblasLower) UL = 'L';
       else
       {
-         cblas_xerbla(2, "cblas_stbsv","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_stbsv","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -51,7 +51,7 @@ void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (TransA == CblasConjTrans) TA = 'C';
       else
       {
-         cblas_xerbla(3, "cblas_stbsv","Illegal TransA setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_stbsv","Illegal TransA setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -60,7 +60,7 @@ void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Diag == CblasNonUnit) DI = 'N';
       else
       {
-         cblas_xerbla(4, "cblas_stbsv","Illegal Diag setting, %d\n", Diag);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_stbsv","Illegal Diag setting, %d\n", Diag);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -80,7 +80,7 @@ void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Uplo == CblasLower) UL = 'U';
       else
       {
-         cblas_xerbla(2, "cblas_stbsv","Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_stbsv","Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -91,7 +91,7 @@ void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (TransA == CblasConjTrans) TA = 'N';
       else
       {
-         cblas_xerbla(3, "cblas_stbsv","Illegal TransA setting, %d\n", TransA);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_stbsv","Illegal TransA setting, %d\n", TransA);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -101,7 +101,7 @@ void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if (Diag == CblasNonUnit) DI = 'N';
       else
       {
-         cblas_xerbla(4, "cblas_stbsv","Illegal Diag setting, %d\n", Diag);
+         API_SUFFIX(cblas_xerbla)(4, "cblas_stbsv","Illegal Diag setting, %d\n", Diag);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -115,7 +115,7 @@ void cblas_stbsv(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       F77_stbsv( F77_UL, F77_TA, F77_DI, &F77_N, &F77_K, A, &F77_lda, X,
                       &F77_incX);
    }
-   else cblas_xerbla(1, "cblas_stbsv", "Illegal layout setting, %d\n", layout);
+   else API_SUFFIX(cblas_xerbla)(1, "cblas_stbsv", "Illegal layout setting, %d\n", layout);
    CBLAS_CallFromC = 0;
    RowMajorStrg = 0;
    return;
