@@ -9,7 +9,7 @@
 
 #include "cblas.h"
 #include "cblas_f77.h"
-void cblas_zherk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
+void API_SUFFIX(cblas_zherk)(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
                  const CBLAS_TRANSPOSE Trans, const CBLAS_INT N, const CBLAS_INT K,
                  const double alpha, const void *A, const CBLAS_INT lda,
                  const double beta, void *C, const CBLAS_INT ldc)
@@ -43,7 +43,7 @@ void cblas_zherk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Uplo == CblasLower ) UL='L';
       else
       {
-         cblas_xerbla(2, "cblas_zherk", "Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(2, "cblas_zherk", "Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -54,7 +54,7 @@ void cblas_zherk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Trans == CblasNoTrans )   TR='N';
       else
       {
-         cblas_xerbla(3, "cblas_zherk", "Illegal Trans setting, %d\n", Trans);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_zherk", "Illegal Trans setting, %d\n", Trans);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -74,7 +74,7 @@ void cblas_zherk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Uplo == CblasLower ) UL='U';
       else
       {
-         cblas_xerbla(3, "cblas_zherk", "Illegal Uplo setting, %d\n", Uplo);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_zherk", "Illegal Uplo setting, %d\n", Uplo);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -84,7 +84,7 @@ void cblas_zherk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       else if ( Trans == CblasNoTrans )   TR='C';
       else
       {
-         cblas_xerbla(3, "cblas_zherk", "Illegal Trans setting, %d\n", Trans);
+         API_SUFFIX(cblas_xerbla)(3, "cblas_zherk", "Illegal Trans setting, %d\n", Trans);
          CBLAS_CallFromC = 0;
          RowMajorStrg = 0;
          return;
@@ -98,7 +98,7 @@ void cblas_zherk(const CBLAS_LAYOUT layout, const CBLAS_UPLO Uplo,
       F77_zherk(F77_UL, F77_TR, &F77_N, &F77_K, &alpha, A, &F77_lda,
                 &beta, C, &F77_ldc);
    }
-   else  cblas_xerbla(1, "cblas_zherk", "Illegal layout setting, %d\n", layout);
+   else  API_SUFFIX(cblas_xerbla)(1, "cblas_zherk", "Illegal layout setting, %d\n", layout);
    CBLAS_CallFromC = 0;
    RowMajorStrg = 0;
    return;
