@@ -3,8 +3,8 @@
 #include "cblas.h"
 #include "cblas_test.h"
 
-int cblas_ok, cblas_lerr, cblas_info;
-int link_xerbla=TRUE;
+CBLAS_INT cblas_ok, cblas_lerr, cblas_info;
+CBLAS_INT link_xerbla=TRUE;
 char *cblas_rout;
 
 #ifdef F77_Char
@@ -14,8 +14,8 @@ void F77_xerbla(char *srname, void *vinfo);
 #endif
 
 void chkxer(void) {
-   extern int cblas_ok, cblas_lerr, cblas_info;
-   extern int link_xerbla;
+   extern CBLAS_INT cblas_ok, cblas_lerr, cblas_info;
+   extern CBLAS_INT link_xerbla;
    extern char *cblas_rout;
    if (cblas_lerr == 1 ) {
       printf("***** ILLEGAL VALUE OF PARAMETER NUMBER %d NOT DETECTED BY %s *****\n", cblas_info, cblas_rout);
@@ -30,15 +30,17 @@ void F77_d3chke(char *rout) {
           B[2] = {0.0,0.0},
           C[2] = {0.0,0.0},
           ALPHA=0.0, BETA=0.0;
-   extern int cblas_info, cblas_lerr, cblas_ok;
+   extern CBLAS_INT cblas_info, cblas_lerr, cblas_ok;
    extern int RowMajorStrg;
    extern char *cblas_rout;
 
+#ifndef HAS_ATTRIBUTE_WEAK_SUPPORT
    if (link_xerbla) /* call these first to link */
    {
       cblas_xerbla(cblas_info,cblas_rout,"");
       F77_xerbla(cblas_rout,&cblas_info);
    }
+#endif
 
    cblas_ok = TRUE ;
    cblas_lerr = PASSED ;
