@@ -3,8 +3,8 @@
 #include "cblas.h"
 #include "cblas_test.h"
 
-int cblas_ok, cblas_lerr, cblas_info;
-int link_xerbla=TRUE;
+CBLAS_INT cblas_ok, cblas_lerr, cblas_info;
+CBLAS_INT link_xerbla=TRUE;
 char *cblas_rout;
 
 #ifdef F77_Char
@@ -14,8 +14,8 @@ void F77_xerbla(char *srname, void *vinfo);
 #endif
 
 void chkxer(void) {
-   extern int cblas_ok, cblas_lerr, cblas_info;
-   extern int link_xerbla;
+   extern CBLAS_INT cblas_ok, cblas_lerr, cblas_info;
+   extern CBLAS_INT link_xerbla;
    extern char *cblas_rout;
    if (cblas_lerr == 1 ) {
       printf("***** ILLEGAL VALUE OF PARAMETER NUMBER %d NOT DETECTED BY %s *****\n", cblas_info, cblas_rout);
@@ -32,7 +32,7 @@ void F77_z2chke(char *rout) {
           ALPHA[2] = {0.0,0.0},
           BETA[2]  = {0.0,0.0},
           RALPHA = 0.0;
-   extern int cblas_info, cblas_lerr, cblas_ok;
+   extern CBLAS_INT cblas_info, cblas_lerr, cblas_ok;
    extern int RowMajorStrg;
    extern char *cblas_rout;
 
