@@ -2,26 +2,26 @@
 *
 *  =========== DOCUMENTATION ===========
 *
-* Online html documentation available at 
-*            http://www.netlib.org/lapack/explore-html/ 
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
 *
 *> \htmlonly
-*> Download CGESVDX + dependencies 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/cgesvdx.f"> 
-*> [TGZ]</a> 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/cgesvdx.f"> 
-*> [ZIP]</a> 
-*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/cgesvdx.f"> 
+*> Download CGESVDX + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/cgesvdx.f">
+*> [TGZ]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/cgesvdx.f">
+*> [ZIP]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/cgesvdx.f">
 *> [TXT]</a>
-*> \endhtmlonly 
+*> \endhtmlonly
 *
 *  Definition:
 *  ===========
 *
-*     SUBROUTINE CGESVDX( JOBU, JOBVT, RANGE, M, N, A, LDA, VL, VU, 
-*    $                    IL, IU, NS, S, U, LDU, VT, LDVT, WORK, 
+*     SUBROUTINE CGESVDX( JOBU, JOBVT, RANGE, M, N, A, LDA, VL, VU,
+*    $                    IL, IU, NS, S, U, LDU, VT, LDVT, WORK,
 *    $                    LWORK, RWORK, IWORK, INFO )
-*      
+*
 *
 *     .. Scalar Arguments ..
 *      CHARACTER          JOBU, JOBVT, RANGE
@@ -31,10 +31,10 @@
 *     .. Array Arguments ..
 *     INTEGER            IWORK( * )
 *     REAL               S( * ), RWORK( * )
-*     COMPLEX            A( LDA, * ), U( LDU, * ), VT( LDVT, * ), 
+*     COMPLEX            A( LDA, * ), U( LDU, * ), VT( LDVT, * ),
 *    $                   WORK( * )
 *     ..
-*  
+*
 *
 *> \par Purpose:
 *  =============
@@ -44,23 +44,23 @@
 *>  CGESVDX computes the singular value decomposition (SVD) of a complex
 *>  M-by-N matrix A, optionally computing the left and/or right singular
 *>  vectors. The SVD is written
-*> 
+*>
 *>      A = U * SIGMA * transpose(V)
-*> 
+*>
 *>  where SIGMA is an M-by-N matrix which is zero except for its
 *>  min(m,n) diagonal elements, U is an M-by-M unitary matrix, and
 *>  V is an N-by-N unitary matrix.  The diagonal elements of SIGMA
 *>  are the singular values of A; they are real and non-negative, and
 *>  are returned in descending order.  The first min(m,n) columns of
 *>  U and V are the left and right singular vectors of A.
-*> 
-*>  CGESVDX uses an eigenvalue problem for obtaining the SVD, which 
-*>  allows for the computation of a subset of singular values and 
+*>
+*>  CGESVDX uses an eigenvalue problem for obtaining the SVD, which
+*>  allows for the computation of a subset of singular values and
 *>  vectors. See SBDSVDX for details.
-*> 
+*>
 *>  Note that the routine returns V**T, not V.
 *> \endverbatim
-*   
+*
 *  Arguments:
 *  ==========
 *
@@ -69,7 +69,7 @@
 *>          JOBU is CHARACTER*1
 *>          Specifies options for computing all or part of the matrix U:
 *>          = 'V':  the first min(m,n) columns of U (the left singular
-*>                  vectors) or as specified by RANGE are returned in 
+*>                  vectors) or as specified by RANGE are returned in
 *>                  the array U;
 *>          = 'N':  no columns of U (no left singular vectors) are
 *>                  computed.
@@ -81,7 +81,7 @@
 *>           Specifies options for computing all or part of the matrix
 *>           V**T:
 *>           = 'V':  the first min(m,n) rows of V**T (the right singular
-*>                   vectors) or as specified by RANGE are returned in 
+*>                   vectors) or as specified by RANGE are returned in
 *>                   the array VT;
 *>           = 'N':  no rows of V**T (no right singular vectors) are
 *>                   computed.
@@ -93,7 +93,7 @@
 *>          = 'A': all singular values will be found.
 *>          = 'V': all singular values in the half-open interval (VL,VU]
 *>                 will be found.
-*>          = 'I': the IL-th through IU-th singular values will be found. 
+*>          = 'I': the IL-th through IU-th singular values will be found.
 *> \endverbatim
 *>
 *> \param[in] M
@@ -124,13 +124,15 @@
 *> \param[in] VL
 *> \verbatim
 *>          VL is REAL
-*>          VL >=0.
+*>          If RANGE='V', the lower bound of the interval to
+*>          be searched for singular values. VU > VL.
+*>          Not referenced if RANGE = 'A' or 'I'.
 *> \endverbatim
 *>
 *> \param[in] VU
 *> \verbatim
 *>          VU is REAL
-*>          If RANGE='V', the lower and upper bounds of the interval to
+*>          If RANGE='V', the upper bound of the interval to
 *>          be searched for singular values. VU > VL.
 *>          Not referenced if RANGE = 'A' or 'I'.
 *> \endverbatim
@@ -138,13 +140,17 @@
 *> \param[in] IL
 *> \verbatim
 *>          IL is INTEGER
+*>          If RANGE='I', the index of the
+*>          smallest singular value to be returned.
+*>          1 <= IL <= IU <= min(M,N), if min(M,N) > 0.
+*>          Not referenced if RANGE = 'A' or 'V'.
 *> \endverbatim
 *>
 *> \param[in] IU
 *> \verbatim
 *>          IU is INTEGER
-*>          If RANGE='I', the indices (in ascending order) of the
-*>          smallest and largest singular values to be returned.
+*>          If RANGE='I', the index of the
+*>          largest singular value to be returned.
 *>          1 <= IL <= IU <= min(M,N), if min(M,N) > 0.
 *>          Not referenced if RANGE = 'A' or 'V'.
 *> \endverbatim
@@ -152,7 +158,7 @@
 *> \param[out] NS
 *> \verbatim
 *>          NS is INTEGER
-*>          The total number of singular values found,  
+*>          The total number of singular values found,
 *>          0 <= NS <= min(M,N).
 *>          If RANGE = 'A', NS = min(M,N); if RANGE = 'I', NS = IU-IL+1.
 *> \endverbatim
@@ -166,11 +172,11 @@
 *> \param[out] U
 *> \verbatim
 *>          U is COMPLEX array, dimension (LDU,UCOL)
-*>          If JOBU = 'V', U contains columns of U (the left singular 
-*>          vectors, stored columnwise) as specified by RANGE; if 
+*>          If JOBU = 'V', U contains columns of U (the left singular
+*>          vectors, stored columnwise) as specified by RANGE; if
 *>          JOBU = 'N', U is not referenced.
-*>          Note: The user must ensure that UCOL >= NS; if RANGE = 'V', 
-*>          the exact value of NS is not known ILQFin advance and an upper 
+*>          Note: The user must ensure that UCOL >= NS; if RANGE = 'V',
+*>          the exact value of NS is not known in advance and an upper
 *>          bound must be used.
 *> \endverbatim
 *>
@@ -184,11 +190,11 @@
 *> \param[out] VT
 *> \verbatim
 *>          VT is COMPLEX array, dimension (LDVT,N)
-*>          If JOBVT = 'V', VT contains the rows of V**T (the right singular 
-*>          vectors, stored rowwise) as specified by RANGE; if JOBVT = 'N', 
+*>          If JOBVT = 'V', VT contains the rows of V**T (the right singular
+*>          vectors, stored rowwise) as specified by RANGE; if JOBVT = 'N',
 *>          VT is not referenced.
-*>          Note: The user must ensure that LDVT >= NS; if RANGE = 'V', 
-*>          the exact value of NS is not known in advance and an upper 
+*>          Note: The user must ensure that LDVT >= NS; if RANGE = 'V',
+*>          the exact value of NS is not known in advance and an upper
 *>          bound must be used.
 *> \endverbatim
 *>
@@ -209,9 +215,9 @@
 *> \verbatim
 *>          LWORK is INTEGER
 *>          The dimension of the array WORK.
-*>          LWORK >= MAX(1,MIN(M,N)*(MIN(M,N)+4)) for the paths (see 
+*>          LWORK >= MAX(1,MIN(M,N)*(MIN(M,N)+4)) for the paths (see
 *>          comments inside the code):
-*>             - PATH 1  (M much larger than N) 
+*>             - PATH 1  (M much larger than N)
 *>             - PATH 1t (N much larger than M)
 *>          LWORK >= MAX(1,MIN(M,N)*2+MAX(M,N)) for the other paths.
 *>          For good performance, LWORK should generally be larger.
@@ -231,8 +237,8 @@
 *> \param[out] IWORK
 *> \verbatim
 *>          IWORK is INTEGER array, dimension (12*MIN(M,N))
-*>          If INFO = 0, the first NS elements of IWORK are zero. If INFO > 0, 
-*>          then IWORK contains the indices of the eigenvectors that failed 
+*>          If INFO = 0, the first NS elements of IWORK are zero. If INFO > 0,
+*>          then IWORK contains the indices of the eigenvectors that failed
 *>          to converge in SBDSVDX/SSTEVX.
 *> \endverbatim
 *>
@@ -250,24 +256,21 @@
 *  Authors:
 *  ========
 *
-*> \author Univ. of Tennessee 
-*> \author Univ. of California Berkeley 
-*> \author Univ. of Colorado Denver 
-*> \author NAG Ltd. 
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
 *
-*> \date November 2015
-*
-*> \ingroup complexGEsing
+*> \ingroup gesvdx
 *
 *  =====================================================================
-      SUBROUTINE CGESVDX( JOBU, JOBVT, RANGE, M, N, A, LDA, VL, VU, 
-     $                    IL, IU, NS, S, U, LDU, VT, LDVT, WORK, 
+      SUBROUTINE CGESVDX( JOBU, JOBVT, RANGE, M, N, A, LDA, VL, VU,
+     $                    IL, IU, NS, S, U, LDU, VT, LDVT, WORK,
      $                    LWORK, RWORK, IWORK, INFO )
 *
-*  -- LAPACK driver routine (version 3.6.0) --
+*  -- LAPACK driver routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     November 2015
 *
 *     .. Scalar Arguments ..
       CHARACTER          JOBU, JOBVT, RANGE
@@ -277,7 +280,7 @@
 *     .. Array Arguments ..
       INTEGER            IWORK( * )
       REAL               S( * ), RWORK( * )
-      COMPLEX            A( LDA, * ), U( LDU, * ), VT( LDVT, * ), 
+      COMPLEX            A( LDA, * ), U( LDU, * ), VT( LDVT, * ),
      $                   WORK( * )
 *     ..
 *
@@ -294,8 +297,8 @@
       CHARACTER          JOBZ, RNGTGK
       LOGICAL            ALLS, INDS, LQUERY, VALS, WANTU, WANTVT
       INTEGER            I, ID, IE, IERR, ILQF, ILTGK, IQRF, ISCL,
-     $                   ITAU, ITAUP, ITAUQ, ITEMP, ITGKZ, IUTGK,
-     $                   J, K, MAXWRK, MINMN, MINWRK, MNTHR
+     $                   ITAU, ITAUP, ITAUQ, ITEMP, ITEMPR, ITGKZ,
+     $                   IUTGK, J, K, MAXWRK, MINMN, MINWRK, MNTHR
       REAL               ABSTOL, ANRM, BIGNUM, EPS, SMLNUM
 *     ..
 *     .. Local Arrays ..
@@ -303,7 +306,8 @@
 *     ..
 *     .. External Subroutines ..
       EXTERNAL           CGEBRD, CGELQF, CGEQRF, CLASCL, CLASET,
-     $                   SLASCL, XERBLA
+     $                   CUNMBR, CUNMQR, CUNMLQ, CLACPY, 
+     $                   SBDSVDX, SLASCL, XERBLA
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME
@@ -367,8 +371,14 @@
          IF( INFO.EQ.0 ) THEN
             IF( WANTU .AND. LDU.LT.M ) THEN
                INFO = -15
-            ELSE IF( WANTVT .AND. LDVT.LT.MINMN ) THEN
-               INFO = -16
+            ELSE IF( WANTVT ) THEN
+               IF( INDS ) THEN
+                   IF( LDVT.LT.IU-IL+1 ) THEN
+                       INFO = -17
+                   END IF
+               ELSE IF( LDVT.LT.MINMN ) THEN
+                   INFO = -17
+               END IF
             END IF
          END IF
       END IF
@@ -390,18 +400,24 @@
 *
 *                 Path 1 (M much larger than N)
 *
-                  MAXWRK = N + N*
-     $                     ILAENV( 1, 'SGEQRF', ' ', M, N, -1, -1 )
-                  MAXWRK = MAX( MAXWRK, N*N + N + 2*N*
-     $                     ILAENV( 1, 'SGEBRD', ' ', N, N, -1, -1 ) )
-                  MINWRK = N*(N+4)
+                  MINWRK = N*(N+5)
+                  MAXWRK = N + N*ILAENV(1,'CGEQRF',' ',M,N,-1,-1)
+                  MAXWRK = MAX(MAXWRK,
+     $                     N*N+2*N+2*N*ILAENV(1,'CGEBRD',' ',N,N,-1,-1))
+                  IF (WANTU .OR. WANTVT) THEN
+                     MAXWRK = MAX(MAXWRK,
+     $                       N*N+2*N+N*ILAENV(1,'CUNMQR','LN',N,N,N,-1))
+                  END IF
                ELSE
 *
 *                 Path 2 (M at least N, but not much larger)
 *
-                  MAXWRK = 2*N + ( M+N )*
-     $                     ILAENV( 1, 'CGEBRD', ' ', M, N, -1, -1 )
-                  MINWRK = 2*N + M
+                  MINWRK = 3*N + M
+                  MAXWRK = 2*N + (M+N)*ILAENV(1,'CGEBRD',' ',M,N,-1,-1)
+                  IF (WANTU .OR. WANTVT) THEN
+                     MAXWRK = MAX(MAXWRK,
+     $                        2*N+N*ILAENV(1,'CUNMQR','LN',N,N,N,-1))
+                  END IF
                END IF
             ELSE
                MNTHR = ILAENV( 6, 'CGESVD', JOBU // JOBVT, M, N, 0, 0 )
@@ -409,18 +425,25 @@
 *
 *                 Path 1t (N much larger than M)
 *
-                  MAXWRK = M + M*
-     $                     ILAENV( 1, 'CGELQF', ' ', M, N, -1, -1 )
-                  MAXWRK = MAX( MAXWRK, M*M + M + 2*M*
-     $                     ILAENV( 1, 'CGEBRD', ' ', M, M, -1, -1 ) )
-                  MINWRK = M*(M+4)
+                  MINWRK = M*(M+5)
+                  MAXWRK = M + M*ILAENV(1,'CGELQF',' ',M,N,-1,-1)
+                  MAXWRK = MAX(MAXWRK,
+     $                     M*M+2*M+2*M*ILAENV(1,'CGEBRD',' ',M,M,-1,-1))
+                  IF (WANTU .OR. WANTVT) THEN
+                     MAXWRK = MAX(MAXWRK,
+     $                       M*M+2*M+M*ILAENV(1,'CUNMQR','LN',M,M,M,-1))
+                  END IF
                ELSE
 *
 *                 Path 2t (N greater than M, but not much larger)
 *
-                  MAXWRK = M*(M*2+19) + ( M+N )*
-     $                     ILAENV( 1, 'CGEBRD', ' ', M, N, -1, -1 )
-                  MINWRK = 2*M + N
+*
+                  MINWRK = 3*M + N
+                  MAXWRK = 2*M + (M+N)*ILAENV(1,'CGEBRD',' ',M,N,-1,-1)
+                  IF (WANTU .OR. WANTVT) THEN
+                     MAXWRK = MAX(MAXWRK,
+     $                        2*M+M*ILAENV(1,'CUNMQR','LN',M,M,M,-1))
+                  END IF
                END IF
             END IF
          END IF
@@ -447,8 +470,6 @@
 *
 *     Set singular values indices accord to RANGE='A'.
 *
-      ALLS = LSAME( RANGE, 'A' )
-      INDS = LSAME( RANGE, 'I' )
       IF( ALLS ) THEN
          RNGTGK = 'I'
          ILTGK = 1
@@ -457,7 +478,7 @@
          RNGTGK = 'I'
          ILTGK = IL
          IUTGK = IU
-      ELSE      
+      ELSE
          RNGTGK = 'V'
          ILTGK = 0
          IUTGK = 0
@@ -501,31 +522,31 @@
             ITEMP = ITAU + N
             CALL CGEQRF( M, N, A, LDA, WORK( ITAU ), WORK( ITEMP ),
      $                   LWORK-ITEMP+1, INFO )
-*  
+*
 *           Copy R into WORK and bidiagonalize it:
 *           (Workspace: need N*N+3*N, prefer N*N+N+2*N*NB)
-*   
+*
             IQRF = ITEMP
             ITAUQ = ITEMP + N*N
             ITAUP = ITAUQ + N
             ITEMP = ITAUP + N
-            ID = 1   
+            ID = 1
             IE = ID + N
             ITGKZ = IE + N
             CALL CLACPY( 'U', N, N, A, LDA, WORK( IQRF ), N )
             CALL CLASET( 'L', N-1, N-1, CZERO, CZERO,
      $                   WORK( IQRF+1 ), N )
-            CALL CGEBRD( N, N, WORK( IQRF ), N, RWORK( ID ), 
+            CALL CGEBRD( N, N, WORK( IQRF ), N, RWORK( ID ),
      $                   RWORK( IE ), WORK( ITAUQ ), WORK( ITAUP ),
      $                   WORK( ITEMP ), LWORK-ITEMP+1, INFO )
-            ITEMP = ITGKZ + N*(N*2+1)
+            ITEMPR = ITGKZ + N*(N*2+1)
 *
 *           Solve eigenvalue problem TGK*Z=Z*S.
-*           (Workspace: need 2*N*N+14*N)          
-*                   
+*           (Workspace: need 2*N*N+14*N)
+*
             CALL SBDSVDX( 'U', JOBZ, RNGTGK, N, RWORK( ID ),
      $                    RWORK( IE ), VL, VU, ILTGK, IUTGK, NS, S,
-     $                    RWORK( ITGKZ ), N*2, RWORK( ITEMP ),
+     $                    RWORK( ITGKZ ), N*2, RWORK( ITEMPR ),
      $                    IWORK, INFO)
 *
 *           If needed, compute left singular vectors.
@@ -539,23 +560,23 @@
                   END DO
                   K = K + N
                END DO
-               CALL CLASET( 'A', M-N, N, CZERO, CZERO, U( N+1,1 ), LDU )
+               CALL CLASET( 'A', M-N, NS, CZERO, CZERO, U( N+1,1 ), LDU)
 *
 *              Call CUNMBR to compute QB*UB.
 *              (Workspace in WORK( ITEMP ): need N, prefer N*NB)
 *
-               CALL CUNMBR( 'Q', 'L', 'N', N, NS, N, WORK( IQRF ), N, 
-     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ), 
+               CALL CUNMBR( 'Q', 'L', 'N', N, NS, N, WORK( IQRF ), N,
+     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
 *
 *              Call CUNMQR to compute Q*(QB*UB).
 *              (Workspace in WORK( ITEMP ): need N, prefer N*NB)
 *
-               CALL CUNMQR( 'L', 'N', M, NS, N, A, LDA, 
+               CALL CUNMQR( 'L', 'N', M, NS, N, A, LDA,
      $                      WORK( ITAU ), U, LDU, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
-            END IF  
-*      
+            END IF
+*
 *           If needed, compute right singular vectors.
 *
             IF( WANTVT) THEN
@@ -571,7 +592,7 @@
 *              Call CUNMBR to compute VB**T * PB**T
 *              (Workspace in WORK( ITEMP ): need N, prefer N*NB)
 *
-               CALL CUNMBR( 'P', 'R', 'C', NS, N, N, WORK( IQRF ), N, 
+               CALL CUNMBR( 'P', 'R', 'C', NS, N, N, WORK( IQRF ), N,
      $                      WORK( ITAUP ), VT, LDVT, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
             END IF
@@ -587,21 +608,21 @@
 *
             ITAUQ = 1
             ITAUP = ITAUQ + N
-            ITEMP = ITAUP + N          
+            ITEMP = ITAUP + N
             ID = 1
             IE = ID + N
             ITGKZ = IE + N
-            CALL CGEBRD( M, N, A, LDA, RWORK( ID ), RWORK( IE ), 
+            CALL CGEBRD( M, N, A, LDA, RWORK( ID ), RWORK( IE ),
      $                   WORK( ITAUQ ), WORK( ITAUP ), WORK( ITEMP ),
      $                   LWORK-ITEMP+1, INFO )
-            ITEMP = ITGKZ + N*(N*2+1)
+            ITEMPR = ITGKZ + N*(N*2+1)
 *
 *           Solve eigenvalue problem TGK*Z=Z*S.
-*           (Workspace: need 2*N*N+14*N)          
-*                     
+*           (Workspace: need 2*N*N+14*N)
+*
             CALL SBDSVDX( 'U', JOBZ, RNGTGK, N, RWORK( ID ),
-     $                    RWORK( IE ), VL, VU, ILTGK, IUTGK, NS, S, 
-     $                    RWORK( ITGKZ ), N*2, RWORK( ITEMP ), 
+     $                    RWORK( IE ), VL, VU, ILTGK, IUTGK, NS, S,
+     $                    RWORK( ITGKZ ), N*2, RWORK( ITEMPR ),
      $                    IWORK, INFO)
 *
 *           If needed, compute left singular vectors.
@@ -609,22 +630,22 @@
             IF( WANTU ) THEN
                K = ITGKZ
                DO I = 1, NS
-                  DO J = 1, N              
+                  DO J = 1, N
                      U( J, I ) = CMPLX( RWORK( K ), ZERO )
                      K = K + 1
                   END DO
                   K = K + N
                END DO
-               CALL CLASET( 'A', M-N, N, CZERO, CZERO, U( N+1,1 ), LDU )
+               CALL CLASET( 'A', M-N, NS, CZERO, CZERO, U( N+1,1 ), LDU)
 *
 *              Call CUNMBR to compute QB*UB.
 *              (Workspace in WORK( ITEMP ): need N, prefer N*NB)
-*   
-               CALL CUNMBR( 'Q', 'L', 'N', M, NS, N, A, LDA, 
-     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ), 
+*
+               CALL CUNMBR( 'Q', 'L', 'N', M, NS, N, A, LDA,
+     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, IERR )
-            END IF  
-*      
+            END IF
+*
 *           If needed, compute right singular vectors.
 *
             IF( WANTVT) THEN
@@ -640,11 +661,11 @@
 *              Call CUNMBR to compute VB**T * PB**T
 *              (Workspace in WORK( ITEMP ): need N, prefer N*NB)
 *
-               CALL CUNMBR( 'P', 'R', 'C', NS, N, N, A, LDA, 
+               CALL CUNMBR( 'P', 'R', 'C', NS, N, N, A, LDA,
      $                      WORK( ITAUP ), VT, LDVT, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, IERR )
             END IF
-         END IF                             
+         END IF
       ELSE
 *
 *        A has more columns than rows. If A has sufficiently more
@@ -653,7 +674,7 @@
          IF( N.GE.MNTHR ) THEN
 *
 *           Path 1t (N much larger than M):
-*           A = L * Q = ( QB * B * PB**T ) * Q 
+*           A = L * Q = ( QB * B * PB**T ) * Q
 *                     = ( QB * ( UB * S * VB**T ) * PB**T ) * Q
 *           U = QB * UB ; V**T = VB**T * PB**T * Q
 *
@@ -668,7 +689,7 @@
 *           Copy L into WORK and bidiagonalize it:
 *           (Workspace in WORK( ITEMP ): need M*M+3*M, prefer M*M+M+2*M*NB)
 *
-            ILQF = ITEMP       
+            ILQF = ITEMP
             ITAUQ = ILQF + M*M
             ITAUP = ITAUQ + M
             ITEMP = ITAUP + M
@@ -676,19 +697,19 @@
             IE = ID + M
             ITGKZ = IE + M
             CALL CLACPY( 'L', M, M, A, LDA, WORK( ILQF ), M )
-            CALL CLASET( 'U', M-1, M-1, CZERO, CZERO, 
+            CALL CLASET( 'U', M-1, M-1, CZERO, CZERO,
      $                   WORK( ILQF+M ), M )
             CALL CGEBRD( M, M, WORK( ILQF ), M, RWORK( ID ),
-     $                   RWORK( IE ), WORK( ITAUQ ), WORK( ITAUP ), 
+     $                   RWORK( IE ), WORK( ITAUQ ), WORK( ITAUP ),
      $                   WORK( ITEMP ), LWORK-ITEMP+1, INFO )
-            ITEMP = ITGKZ + M*(M*2+1)
+            ITEMPR = ITGKZ + M*(M*2+1)
 *
 *           Solve eigenvalue problem TGK*Z=Z*S.
-*           (Workspace: need 2*M*M+14*M)          
+*           (Workspace: need 2*M*M+14*M)
 *
             CALL SBDSVDX( 'U', JOBZ, RNGTGK, M, RWORK( ID ),
-     $                    RWORK( IE ), VL, VU, ILTGK, IUTGK, NS, S, 
-     $                    RWORK( ITGKZ ), M*2, RWORK( ITEMP ), 
+     $                    RWORK( IE ), VL, VU, ILTGK, IUTGK, NS, S,
+     $                    RWORK( ITGKZ ), M*2, RWORK( ITEMPR ),
      $                    IWORK, INFO)
 *
 *           If needed, compute left singular vectors.
@@ -706,11 +727,11 @@
 *              Call CUNMBR to compute QB*UB.
 *              (Workspace in WORK( ITEMP ): need M, prefer M*NB)
 *
-               CALL CUNMBR( 'Q', 'L', 'N', M, NS, M, WORK( ILQF ), M, 
-     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ), 
+               CALL CUNMBR( 'Q', 'L', 'N', M, NS, M, WORK( ILQF ), M,
+     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
-            END IF  
-*      
+            END IF
+*
 *           If needed, compute right singular vectors.
 *
             IF( WANTVT) THEN
@@ -722,52 +743,52 @@
                   END DO
                   K = K + M
                END DO
-               CALL CLASET( 'A', M, N-M, CZERO, CZERO, 
+               CALL CLASET( 'A', NS, N-M, CZERO, CZERO,
      $                      VT( 1,M+1 ), LDVT )
 *
 *              Call CUNMBR to compute (VB**T)*(PB**T)
 *              (Workspace in WORK( ITEMP ): need M, prefer M*NB)
 *
-               CALL CUNMBR( 'P', 'R', 'C', NS, M, M, WORK( ILQF ), M, 
+               CALL CUNMBR( 'P', 'R', 'C', NS, M, M, WORK( ILQF ), M,
      $                      WORK( ITAUP ), VT, LDVT, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
 *
 *              Call CUNMLQ to compute ((VB**T)*(PB**T))*Q.
 *              (Workspace in WORK( ITEMP ): need M, prefer M*NB)
 *
-               CALL CUNMLQ( 'R', 'N', NS, N, M, A, LDA, 
+               CALL CUNMLQ( 'R', 'N', NS, N, M, A, LDA,
      $                      WORK( ITAU ), VT, LDVT, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
-            END IF  
+            END IF
          ELSE
 *
 *           Path 2t (N greater than M, but not much larger)
 *           Reduce to bidiagonal form without LQ decomposition
 *           A = QB * B * PB**T = QB * ( UB * S * VB**T ) * PB**T
-*           U = QB * UB; V**T = VB**T * PB**T           
+*           U = QB * UB; V**T = VB**T * PB**T
 *
 *           Bidiagonalize A
 *           (Workspace: need 2*M+N, prefer 2*M+(M+N)*NB)
-*            
+*
             ITAUQ = 1
             ITAUP = ITAUQ + M
             ITEMP = ITAUP + M
             ID = 1
             IE = ID + M
             ITGKZ = IE + M
-            CALL CGEBRD( M, N, A, LDA, RWORK( ID ), RWORK( IE ), 
+            CALL CGEBRD( M, N, A, LDA, RWORK( ID ), RWORK( IE ),
      $                   WORK( ITAUQ ), WORK( ITAUP ), WORK( ITEMP ),
      $                   LWORK-ITEMP+1, INFO )
-            ITEMP = ITGKZ + M*(M*2+1)
+            ITEMPR = ITGKZ + M*(M*2+1)
 *
 *           Solve eigenvalue problem TGK*Z=Z*S.
-*           (Workspace: need 2*M*M+14*M)          
-*          
-            CALL SBDSVDX( 'L', JOBZ, RNGTGK, M, RWORK( ID ), 
-     $                    RWORK( IE ), VL, VU, ILTGK, IUTGK, NS, S, 
-     $                    RWORK( ITGKZ ), M*2, RWORK( ITEMP ), 
+*           (Workspace: need 2*M*M+14*M)
+*
+            CALL SBDSVDX( 'L', JOBZ, RNGTGK, M, RWORK( ID ),
+     $                    RWORK( IE ), VL, VU, ILTGK, IUTGK, NS, S,
+     $                    RWORK( ITGKZ ), M*2, RWORK( ITEMPR ),
      $                    IWORK, INFO)
-* 
+*
 *           If needed, compute left singular vectors.
 *
             IF( WANTU ) THEN
@@ -783,11 +804,11 @@
 *              Call CUNMBR to compute QB*UB.
 *              (Workspace in WORK( ITEMP ): need M, prefer M*NB)
 *
-               CALL CUNMBR( 'Q', 'L', 'N', M, NS, N, A, LDA, 
-     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ), 
+               CALL CUNMBR( 'Q', 'L', 'N', M, NS, N, A, LDA,
+     $                      WORK( ITAUQ ), U, LDU, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
-            END IF  
-*      
+            END IF
+*
 *           If needed, compute right singular vectors.
 *
             IF( WANTVT) THEN
@@ -799,16 +820,16 @@
                   END DO
                   K = K + M
                END DO
-               CALL CLASET( 'A', M, N-M, CZERO, CZERO, 
+               CALL CLASET( 'A', NS, N-M, CZERO, CZERO,
      $                      VT( 1,M+1 ), LDVT )
 *
 *              Call CUNMBR to compute VB**T * PB**T
 *              (Workspace in WORK( ITEMP ): need M, prefer M*NB)
 *
-               CALL CUNMBR( 'P', 'R', 'C', NS, N, M, A, LDA, 
+               CALL CUNMBR( 'P', 'R', 'C', NS, N, M, A, LDA,
      $                      WORK( ITAUP ), VT, LDVT, WORK( ITEMP ),
      $                      LWORK-ITEMP+1, INFO )
-            END IF 
+            END IF
          END IF
       END IF
 *
