@@ -117,9 +117,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date April 2012
-*
-*> \ingroup complexHEcomputational
+*> \ingroup heequb
 *
 *> \par References:
 *  ================
@@ -132,10 +130,9 @@
 *  =====================================================================
       SUBROUTINE CHEEQUB( UPLO, N, A, LDA, S, SCOND, AMAX, WORK, INFO )
 *
-*  -- LAPACK computational routine (version 3.7.0) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     April 2012
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, N
@@ -168,7 +165,7 @@
       EXTERNAL           LSAME, SLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CLASSQ
+      EXTERNAL           CLASSQ, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, AIMAG, INT, LOG, MAX, MIN, REAL, SQRT
@@ -266,7 +263,7 @@
 *        avg = s^T beta / n
          AVG = 0.0E0
          DO I = 1, N
-            AVG = AVG + S( I )*WORK( I )
+            AVG = AVG + REAL( S( I )*WORK( I ) )
          END DO
          AVG = AVG / N
 
@@ -283,8 +280,8 @@
             T = CABS1( A( I, I ) )
             SI = S( I )
             C2 = ( N-1 ) * T
-            C1 = ( N-2 ) * ( WORK( I ) - T*SI )
-            C0 = -(T*SI)*SI + 2*WORK( I )*SI - N*AVG
+            C1 = REAL( ( N-2 ) * ( WORK( I ) - T*SI ) )
+            C0 = REAL( -(T*SI)*SI + 2*WORK( I )*SI - N*AVG )
             D = C1*C1 - 4*C0*C2
 
             IF ( D .LE. 0 ) THEN
@@ -319,7 +316,7 @@
                END DO
             END IF
 
-            AVG = AVG + ( U + WORK( I ) ) * D / N
+            AVG = AVG + REAL( ( U + WORK( I ) ) * D / N )
             S( I ) = SI
          END DO
       END DO
