@@ -117,7 +117,7 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \ingroup complexGBauxiliary
+*> \ingroup langb
 *
 *  =====================================================================
       REAL             FUNCTION CLANGB( NORM, N, KL, KU, AB, LDAB,
@@ -127,7 +127,6 @@
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
-      IMPLICIT NONE
 *     .. Scalar Arguments ..
       CHARACTER          NORM
       INTEGER            KL, KU, LDAB, N
@@ -145,17 +144,14 @@
 *     ..
 *     .. Local Scalars ..
       INTEGER            I, J, K, L
-      REAL               SUM, VALUE, TEMP
-*     ..
-*     .. Local Arrays ..
-      REAL               SSQ( 2 ), COLSSQ( 2 )
+      REAL               SCALE, SUM, VALUE, TEMP
 *     ..
 *     .. External Functions ..
       LOGICAL            LSAME, SISNAN
       EXTERNAL           LSAME, SISNAN
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           CLASSQ, SCOMBSSQ
+      EXTERNAL           CLASSQ
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, MIN, SQRT
@@ -208,22 +204,15 @@
       ELSE IF( ( LSAME( NORM, 'F' ) ) .OR. ( LSAME( NORM, 'E' ) ) ) THEN
 *
 *        Find normF(A).
-*        SSQ(1) is scale
-*        SSQ(2) is sum-of-squares
-*        For better accuracy, sum each column separately.
 *
-         SSQ( 1 ) = ZERO
-         SSQ( 2 ) = ONE
+         SCALE = ZERO
+         SUM = ONE
          DO 90 J = 1, N
             L = MAX( 1, J-KU )
             K = KU + 1 - J + L
-            COLSSQ( 1 ) = ZERO
-            COLSSQ( 2 ) = ONE
-            CALL CLASSQ( MIN( N, J+KL )-L+1, AB( K, J ), 1,
-     $                   COLSSQ( 1 ), COLSSQ( 2 ) )
-            CALL SCOMBSSQ( SSQ, COLSSQ )
+            CALL CLASSQ( MIN( N, J+KL )-L+1, AB( K, J ), 1, SCALE, SUM )
    90    CONTINUE
-         VALUE = SSQ( 1 )*SQRT( SSQ( 2 ) )
+         VALUE = SCALE*SQRT( SUM )
       END IF
 *
       CLANGB = VALUE
