@@ -1,10 +1,171 @@
+*> \brief \b SLAQTR solves a real quasi-triangular system of equations, or a complex quasi-triangular system of special form, in real arithmetic.
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*> \htmlonly
+*> Download SLAQTR + dependencies
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.tgz?format=tgz&filename=/lapack/lapack_routine/slaqtr.f">
+*> [TGZ]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.zip?format=zip&filename=/lapack/lapack_routine/slaqtr.f">
+*> [ZIP]</a>
+*> <a href="http://www.netlib.org/cgi-bin/netlibfiles.txt?format=txt&filename=/lapack/lapack_routine/slaqtr.f">
+*> [TXT]</a>
+*> \endhtmlonly
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SLAQTR( LTRAN, LREAL, N, T, LDT, B, W, SCALE, X, WORK,
+*                          INFO )
+*
+*       .. Scalar Arguments ..
+*       LOGICAL            LREAL, LTRAN
+*       INTEGER            INFO, LDT, N
+*       REAL               SCALE, W
+*       ..
+*       .. Array Arguments ..
+*       REAL               B( * ), T( LDT, * ), WORK( * ), X( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> SLAQTR solves the real quasi-triangular system
+*>
+*>              op(T)*p = scale*c,               if LREAL = .TRUE.
+*>
+*> or the complex quasi-triangular systems
+*>
+*>            op(T + iB)*(p+iq) = scale*(c+id),  if LREAL = .FALSE.
+*>
+*> in real arithmetic, where T is upper quasi-triangular.
+*> If LREAL = .FALSE., then the first diagonal block of T must be
+*> 1 by 1, B is the specially structured matrix
+*>
+*>                B = [ b(1) b(2) ... b(n) ]
+*>                    [       w            ]
+*>                    [           w        ]
+*>                    [              .     ]
+*>                    [                 w  ]
+*>
+*> op(A) = A or A**T, A**T denotes the transpose of
+*> matrix A.
+*>
+*> On input, X = [ c ].  On output, X = [ p ].
+*>               [ d ]                  [ q ]
+*>
+*> This subroutine is designed for the condition number estimation
+*> in routine STRSNA.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] LTRAN
+*> \verbatim
+*>          LTRAN is LOGICAL
+*>          On entry, LTRAN specifies the option of conjugate transpose:
+*>             = .FALSE.,    op(T+i*B) = T+i*B,
+*>             = .TRUE.,     op(T+i*B) = (T+i*B)**T.
+*> \endverbatim
+*>
+*> \param[in] LREAL
+*> \verbatim
+*>          LREAL is LOGICAL
+*>          On entry, LREAL specifies the input matrix structure:
+*>             = .FALSE.,    the input is complex
+*>             = .TRUE.,     the input is real
+*> \endverbatim
+*>
+*> \param[in] N
+*> \verbatim
+*>          N is INTEGER
+*>          On entry, N specifies the order of T+i*B. N >= 0.
+*> \endverbatim
+*>
+*> \param[in] T
+*> \verbatim
+*>          T is REAL array, dimension (LDT,N)
+*>          On entry, T contains a matrix in Schur canonical form.
+*>          If LREAL = .FALSE., then the first diagonal block of T must
+*>          be 1 by 1.
+*> \endverbatim
+*>
+*> \param[in] LDT
+*> \verbatim
+*>          LDT is INTEGER
+*>          The leading dimension of the matrix T. LDT >= max(1,N).
+*> \endverbatim
+*>
+*> \param[in] B
+*> \verbatim
+*>          B is REAL array, dimension (N)
+*>          On entry, B contains the elements to form the matrix
+*>          B as described above.
+*>          If LREAL = .TRUE., B is not referenced.
+*> \endverbatim
+*>
+*> \param[in] W
+*> \verbatim
+*>          W is REAL
+*>          On entry, W is the diagonal element of the matrix B.
+*>          If LREAL = .TRUE., W is not referenced.
+*> \endverbatim
+*>
+*> \param[out] SCALE
+*> \verbatim
+*>          SCALE is REAL
+*>          On exit, SCALE is the scale factor.
+*> \endverbatim
+*>
+*> \param[in,out] X
+*> \verbatim
+*>          X is REAL array, dimension (2*N)
+*>          On entry, X contains the right hand side of the system.
+*>          On exit, X is overwritten by the solution.
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is REAL array, dimension (N)
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>          On exit, INFO is set to
+*>             0: successful exit.
+*>               1: the some diagonal 1 by 1 block has been perturbed by
+*>                  a small number SMIN to keep nonsingularity.
+*>               2: the some diagonal 2 by 2 block has been perturbed by
+*>                  a small number in SLALN2 to keep nonsingularity.
+*>          NOTE: In the interests of speed, this routine does not
+*>                check the inputs for errors.
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup laqtr
+*
+*  =====================================================================
       SUBROUTINE SLAQTR( LTRAN, LREAL, N, T, LDT, B, W, SCALE, X, WORK,
      $                   INFO )
 *
-*  -- LAPACK auxiliary routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     October 31, 1992
+*  -- LAPACK auxiliary routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       LOGICAL            LREAL, LTRAN
@@ -15,88 +176,6 @@
       REAL               B( * ), T( LDT, * ), WORK( * ), X( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  SLAQTR solves the real quasi-triangular system
-*
-*               op(T)*p = scale*c,               if LREAL = .TRUE.
-*
-*  or the complex quasi-triangular systems
-*
-*             op(T + iB)*(p+iq) = scale*(c+id),  if LREAL = .FALSE.
-*
-*  in real arithmetic, where T is upper quasi-triangular.
-*  If LREAL = .FALSE., then the first diagonal block of T must be
-*  1 by 1, B is the specially structured matrix
-*
-*                 B = [ b(1) b(2) ... b(n) ]
-*                     [       w            ]
-*                     [           w        ]
-*                     [              .     ]
-*                     [                 w  ]
-*
-*  op(A) = A or A', A' denotes the conjugate transpose of
-*  matrix A.
-*
-*  On input, X = [ c ].  On output, X = [ p ].
-*                [ d ]                  [ q ]
-*
-*  This subroutine is designed for the condition number estimation
-*  in routine STRSNA.
-*
-*  Arguments
-*  =========
-*
-*  LTRAN   (input) LOGICAL
-*          On entry, LTRAN specifies the option of conjugate transpose:
-*             = .FALSE.,    op(T+i*B) = T+i*B,
-*             = .TRUE.,     op(T+i*B) = (T+i*B)'.
-*
-*  LREAL   (input) LOGICAL
-*          On entry, LREAL specifies the input matrix structure:
-*             = .FALSE.,    the input is complex
-*             = .TRUE.,     the input is real
-*
-*  N       (input) INTEGER
-*          On entry, N specifies the order of T+i*B. N >= 0.
-*
-*  T       (input) REAL array, dimension (LDT,N)
-*          On entry, T contains a matrix in Schur canonical form.
-*          If LREAL = .FALSE., then the first diagonal block of T must
-*          be 1 by 1.
-*
-*  LDT     (input) INTEGER
-*          The leading dimension of the matrix T. LDT >= max(1,N).
-*
-*  B       (input) REAL array, dimension (N)
-*          On entry, B contains the elements to form the matrix
-*          B as described above.
-*          If LREAL = .TRUE., B is not referenced.
-*
-*  W       (input) REAL
-*          On entry, W is the diagonal element of the matrix B.
-*          If LREAL = .TRUE., W is not referenced.
-*
-*  SCALE   (output) REAL
-*          On exit, SCALE is the scale factor.
-*
-*  X       (input/output) REAL array, dimension (2*N)
-*          On entry, X contains the right hand side of the system.
-*          On exit, X is overwritten by the solution.
-*
-*  WORK    (workspace) REAL array, dimension (N)
-*
-*  INFO    (output) INTEGER
-*          On exit, INFO is set to
-*             0: successful exit.
-*               1: the some diagonal 1 by 1 block has been perturbed by
-*                  a small number SMIN to keep nonsingularity.
-*               2: the some diagonal 2 by 2 block has been perturbed by
-*                  a small number in SLALN2 to keep nonsingularity.
-*          NOTE: In the interests of speed, this routine does not
-*                check the inputs for errors.
-*
 * =====================================================================
 *
 *     .. Parameters ..
@@ -187,10 +266,11 @@
                J1 = J
                J2 = J
                JNEXT = J - 1
-               IF( J.GT.1 .AND. T( J, J-1 ).NE.ZERO ) THEN
-                  J1 = J - 1
-                  J2 = J
-                  JNEXT = J - 2
+               IF( J.GT.1 ) THEN
+                  IF( T( J, J-1 ).NE.ZERO ) THEN
+                     J1 = J - 1
+                     JNEXT = J - 2
+                  END IF
                END IF
 *
                IF( J1.EQ.J2 ) THEN
@@ -289,7 +369,7 @@
 *
          ELSE
 *
-*           Solve T'*p = scale*c
+*           Solve T**T*p = scale*c
 *
             JNEXT = 1
             DO 40 J = 1, N
@@ -298,10 +378,11 @@
                J1 = J
                J2 = J
                JNEXT = J + 1
-               IF( J.LT.N .AND. T( J+1, J ).NE.ZERO ) THEN
-                  J1 = J
-                  J2 = J + 1
-                  JNEXT = J + 2
+               IF( J.LT.N ) THEN
+                  IF( T( J+1, J ).NE.ZERO ) THEN
+                     J2 = J + 1
+                     JNEXT = J + 2
+                  END IF
                END IF
 *
                IF( J1.EQ.J2 ) THEN
@@ -398,10 +479,11 @@
                J1 = J
                J2 = J
                JNEXT = J - 1
-               IF( J.GT.1 .AND. T( J, J-1 ).NE.ZERO ) THEN
-                  J1 = J - 1
-                  J2 = J
-                  JNEXT = J - 2
+               IF( J.GT.1 ) THEN
+                  IF( T( J, J-1 ).NE.ZERO ) THEN
+                     J1 = J - 1
+                     JNEXT = J - 2
+                  END IF
                END IF
 *
                IF( J1.EQ.J2 ) THEN
@@ -529,7 +611,7 @@
 *
          ELSE
 *
-*           Solve (T + iB)'*(p+iq) = c+id
+*           Solve (T + iB)**T*(p+iq) = c+id
 *
             JNEXT = 1
             DO 80 J = 1, N
@@ -538,10 +620,11 @@
                J1 = J
                J2 = J
                JNEXT = J + 1
-               IF( J.LT.N .AND. T( J+1, J ).NE.ZERO ) THEN
-                  J1 = J
-                  J2 = J + 1
-                  JNEXT = J + 2
+               IF( J.LT.N ) THEN
+                  IF( T( J+1, J ).NE.ZERO ) THEN
+                     J2 = J + 1
+                     JNEXT = J + 2
+                  END IF
                END IF
 *
                IF( J1.EQ.J2 ) THEN
