@@ -136,18 +136,15 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date June 2017
-*
-*> \ingroup complex16HEcomputational
+*> \ingroup lahef_aa
 *
 *  =====================================================================
       SUBROUTINE ZLAHEF_AA( UPLO, J1, M, NB, A, LDA, IPIV,
      $                      H, LDH, WORK )
 *
-*  -- LAPACK computational routine (version 3.7.1) --
+*  -- LAPACK computational routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     June 2017
 *
       IMPLICIT NONE
 *
@@ -166,7 +163,7 @@
       PARAMETER    ( ZERO = (0.0D+0, 0.0D+0), ONE = (1.0D+0, 0.0D+0) )
 *
 *     .. Local Scalars ..
-      INTEGER      J, K, K1, I1, I2
+      INTEGER      J, K, K1, I1, I2, MJ
       COMPLEX*16   PIV, ALPHA
 *     ..
 *     .. External Functions ..
@@ -175,7 +172,8 @@
       EXTERNAL     LSAME, ILAENV, IZAMAX
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL     XERBLA
+      EXTERNAL     ZGEMM, ZGEMV, ZAXPY, ZLACGV, ZCOPY, ZSCAL, ZSWAP,
+     $             ZLASET, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC    DBLE, DCONJG, MAX
@@ -205,6 +203,14 @@
 *         > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
 *
          K = J1+J-1
+         IF( J.EQ.M ) THEN
+*
+*            Only need to compute T(J, J)
+*
+             MJ = 1
+         ELSE
+             MJ = M-J+1
+         END IF
 *
 *        H(J:N, J) := A(J, J:N) - H(J:N, 1:(J-1)) * L(J1:(J-1), J),
 *         where H(J:N, J) has been initialized to be A(J, J:N)
@@ -218,7 +224,7 @@
 *           first column
 *
             CALL ZLACGV( J-K1, A( 1, J ), 1 )
-            CALL ZGEMV( 'No transpose', M-J+1, J-K1,
+            CALL ZGEMV( 'No transpose', MJ, J-K1,
      $                 -ONE, H( J, K1 ), LDH,
      $                       A( 1, J ), 1,
      $                  ONE, H( J, J ), 1 )
@@ -227,7 +233,7 @@
 *
 *        Copy H(i:n, i) into WORK
 *
-         CALL ZCOPY( M-J+1, H( J, J ), 1, WORK( 1 ), 1 )
+         CALL ZCOPY( MJ, H( J, J ), 1, WORK( 1 ), 1 )
 *
          IF( J.GT.K1 ) THEN
 *
@@ -235,7 +241,7 @@
 *            where A(J-1, J) stores T(J-1, J) and A(J-2, J:N) stores U(J-1, J:N)
 *
             ALPHA = -DCONJG( A( K-1, J ) )
-            CALL ZAXPY( M-J+1, ALPHA, A( K-2, J ), LDA, WORK( 1 ), 1 )
+            CALL ZAXPY( MJ, ALPHA, A( K-2, J ), LDA, WORK( 1 ), 1 )
          END IF
 *
 *        Set A(J, J) = T(J, J)
@@ -279,8 +285,9 @@
 *
 *              Swap A(I1, I2+1:N) with A(I2, I2+1:N)
 *
-               CALL ZSWAP( M-I2, A( J1+I1-1, I2+1 ), LDA,
-     $                           A( J1+I2-1, I2+1 ), LDA )
+               IF( I2.LT.M )
+     $            CALL ZSWAP( M-I2, A( J1+I1-1, I2+1 ), LDA,
+     $                              A( J1+I2-1, I2+1 ), LDA )
 *
 *              Swap A(I1, I1) with A(I2,I2)
 *
@@ -320,13 +327,15 @@
 *           Compute L(J+2, J+1) = WORK( 3:N ) / T(J, J+1),
 *            where A(J, J+1) = T(J, J+1) and A(J+2:N, J) = L(J+2:N, J+1)
 *
-            IF( A( K, J+1 ).NE.ZERO ) THEN
-               ALPHA = ONE / A( K, J+1 )
-               CALL ZCOPY( M-J-1, WORK( 3 ), 1, A( K, J+2 ), LDA )
-               CALL ZSCAL( M-J-1, ALPHA, A( K, J+2 ), LDA )
-            ELSE
-               CALL ZLASET( 'Full', 1, M-J-1, ZERO, ZERO,
-     $                      A( K, J+2 ), LDA)
+            IF( J.LT.(M-1) ) THEN
+               IF( A( K, J+1 ).NE.ZERO ) THEN
+                  ALPHA = ONE / A( K, J+1 )
+                  CALL ZCOPY( M-J-1, WORK( 3 ), 1, A( K, J+2 ), LDA )
+                  CALL ZSCAL( M-J-1, ALPHA, A( K, J+2 ), LDA )
+               ELSE
+                  CALL ZLASET( 'Full', 1, M-J-1, ZERO, ZERO,
+     $                         A( K, J+2 ), LDA)
+               END IF
             END IF
          END IF
          J = J + 1
@@ -349,6 +358,14 @@
 *         > for the rest of the columns, J1 is 2, and J1+J-1 is J+1,
 *
          K = J1+J-1
+         IF( J.EQ.M ) THEN
+*
+*            Only need to compute T(J, J)
+*
+             MJ = 1
+         ELSE
+             MJ = M-J+1
+         END IF
 *
 *        H(J:N, J) := A(J:N, J) - H(J:N, 1:(J-1)) * L(J, J1:(J-1))^T,
 *         where H(J:N, J) has been initialized to be A(J:N, J)
@@ -362,7 +379,7 @@
 *           first column
 *
             CALL ZLACGV( J-K1, A( J, 1 ), LDA )
-            CALL ZGEMV( 'No transpose', M-J+1, J-K1,
+            CALL ZGEMV( 'No transpose', MJ, J-K1,
      $                 -ONE, H( J, K1 ), LDH,
      $                       A( J, 1 ), LDA,
      $                  ONE, H( J, J ), 1 )
@@ -371,7 +388,7 @@
 *
 *        Copy H(J:N, J) into WORK
 *
-         CALL ZCOPY( M-J+1, H( J, J ), 1, WORK( 1 ), 1 )
+         CALL ZCOPY( MJ, H( J, J ), 1, WORK( 1 ), 1 )
 *
          IF( J.GT.K1 ) THEN
 *
@@ -379,7 +396,7 @@
 *            where A(J-1, J) = T(J-1, J) and A(J, J-2) = L(J, J-1)
 *
             ALPHA = -DCONJG( A( J, K-1 ) )
-            CALL ZAXPY( M-J+1, ALPHA, A( J, K-2 ), 1, WORK( 1 ), 1 )
+            CALL ZAXPY( MJ, ALPHA, A( J, K-2 ), 1, WORK( 1 ), 1 )
          END IF
 *
 *        Set A(J, J) = T(J, J)
@@ -423,8 +440,9 @@
 *
 *              Swap A(I2+1:N, I1) with A(I2+1:N, I2)
 *
-               CALL ZSWAP( M-I2, A( I2+1, J1+I1-1 ), 1,
-     $                           A( I2+1, J1+I2-1 ), 1 )
+               IF( I2.LT.M )
+     $            CALL ZSWAP( M-I2, A( I2+1, J1+I1-1 ), 1,
+     $                              A( I2+1, J1+I2-1 ), 1 )
 *
 *              Swap A(I1, I1) with A(I2, I2)
 *
@@ -464,13 +482,15 @@
 *           Compute L(J+2, J+1) = WORK( 3:N ) / T(J, J+1),
 *            where A(J, J+1) = T(J, J+1) and A(J+2:N, J) = L(J+2:N, J+1)
 *
-            IF( A( J+1, K ).NE.ZERO ) THEN
-               ALPHA = ONE / A( J+1, K )
-               CALL ZCOPY( M-J-1, WORK( 3 ), 1, A( J+2, K ), 1 )
-               CALL ZSCAL( M-J-1, ALPHA, A( J+2, K ), 1 )
-            ELSE
-               CALL ZLASET( 'Full', M-J-1, 1, ZERO, ZERO,
-     $                      A( J+2, K ), LDA )
+            IF( J.LT.(M-1) ) THEN
+               IF( A( J+1, K ).NE.ZERO ) THEN
+                  ALPHA = ONE / A( J+1, K )
+                  CALL ZCOPY( M-J-1, WORK( 3 ), 1, A( J+2, K ), 1 )
+                  CALL ZSCAL( M-J-1, ALPHA, A( J+2, K ), 1 )
+               ELSE
+                  CALL ZLASET( 'Full', M-J-1, 1, ZERO, ZERO,
+     $                         A( J+2, K ), LDA )
+               END IF
             END IF
          END IF
          J = J + 1
