@@ -1,9 +1,96 @@
+*> \brief \b DGET37
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE DGET37( RMAX, LMAX, NINFO, KNT, NIN )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            KNT, NIN
+*       ..
+*       .. Array Arguments ..
+*       INTEGER            LMAX( 3 ), NINFO( 3 )
+*       DOUBLE PRECISION   RMAX( 3 )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*> DGET37 tests DTRSNA, a routine for estimating condition numbers of
+*> eigenvalues and/or right eigenvectors of a matrix.
+*>
+*> The test matrices are read from a file with logical unit number NIN.
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[out] RMAX
+*> \verbatim
+*>          RMAX is DOUBLE PRECISION array, dimension (3)
+*>          Value of the largest test ratio.
+*>          RMAX(1) = largest ratio comparing different calls to DTRSNA
+*>          RMAX(2) = largest error in reciprocal condition
+*>                    numbers taking their conditioning into account
+*>          RMAX(3) = largest error in reciprocal condition
+*>                    numbers not taking their conditioning into
+*>                    account (may be larger than RMAX(2))
+*> \endverbatim
+*>
+*> \param[out] LMAX
+*> \verbatim
+*>          LMAX is INTEGER array, dimension (3)
+*>          LMAX(i) is example number where largest test ratio
+*>          RMAX(i) is achieved. Also:
+*>          If DGEHRD returns INFO nonzero on example i, LMAX(1)=i
+*>          If DHSEQR returns INFO nonzero on example i, LMAX(2)=i
+*>          If DTRSNA returns INFO nonzero on example i, LMAX(3)=i
+*> \endverbatim
+*>
+*> \param[out] NINFO
+*> \verbatim
+*>          NINFO is INTEGER array, dimension (3)
+*>          NINFO(1) = No. of times DGEHRD returned INFO nonzero
+*>          NINFO(2) = No. of times DHSEQR returned INFO nonzero
+*>          NINFO(3) = No. of times DTRSNA returned INFO nonzero
+*> \endverbatim
+*>
+*> \param[out] KNT
+*> \verbatim
+*>          KNT is INTEGER
+*>          Total number of examples tested.
+*> \endverbatim
+*>
+*> \param[in] NIN
+*> \verbatim
+*>          NIN is INTEGER
+*>          Input logical unit number
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup double_eig
+*
+*  =====================================================================
       SUBROUTINE DGET37( RMAX, LMAX, NINFO, KNT, NIN )
 *
-*  -- LAPACK test routine (version 3.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     June 30, 1999
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       INTEGER            KNT, NIN
@@ -13,44 +100,6 @@
       DOUBLE PRECISION   RMAX( 3 )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*  DGET37 tests DTRSNA, a routine for estimating condition numbers of
-*  eigenvalues and/or right eigenvectors of a matrix.
-*
-*  The test matrices are read from a file with logical unit number NIN.
-*
-*  Arguments
-*  ==========
-*
-*  RMAX    (output) DOUBLE PRECISION array, dimension (3)
-*          Value of the largest test ratio.
-*          RMAX(1) = largest ratio comparing different calls to DTRSNA
-*          RMAX(2) = largest error in reciprocal condition
-*                    numbers taking their conditioning into account
-*          RMAX(3) = largest error in reciprocal condition
-*                    numbers not taking their conditioning into
-*                    account (may be larger than RMAX(2))
-*
-*  LMAX    (output) INTEGER array, dimension (3)
-*          LMAX(i) is example number where largest test ratio
-*          RMAX(i) is achieved. Also:
-*          If DGEHRD returns INFO nonzero on example i, LMAX(1)=i
-*          If DHSEQR returns INFO nonzero on example i, LMAX(2)=i
-*          If DTRSNA returns INFO nonzero on example i, LMAX(3)=i
-*
-*  NINFO   (output) INTEGER array, dimension (3)
-*          NINFO(1) = No. of times DGEHRD returned INFO nonzero
-*          NINFO(2) = No. of times DHSEQR returned INFO nonzero
-*          NINFO(3) = No. of times DTRSNA returned INFO nonzero
-*
-*  KNT     (output) INTEGER
-*          Total number of examples tested.
-*
-*  NIN     (input) INTEGER
-*          Input logical unit number
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -82,8 +131,8 @@
       EXTERNAL           DLAMCH, DLANGE
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           DCOPY, DGEHRD, DHSEQR, DLABAD, DLACPY, DSCAL,
-     $                   DTREVC, DTRSNA
+      EXTERNAL           DCOPY, DGEHRD, DHSEQR, DLACPY, DSCAL, DTREVC,
+     $                   DTRSNA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          DBLE, MAX, SQRT
@@ -93,7 +142,6 @@
       EPS = DLAMCH( 'P' )
       SMLNUM = DLAMCH( 'S' ) / EPS
       BIGNUM = ONE / SMLNUM
-      CALL DLABAD( SMLNUM, BIGNUM )
 *
 *     EPSIN = 2**(-24) = precision to which input data computed
 *
