@@ -1,11 +1,394 @@
+*> \brief \b SDRVES
+*
+*  =========== DOCUMENTATION ===========
+*
+* Online html documentation available at
+*            http://www.netlib.org/lapack/explore-html/
+*
+*  Definition:
+*  ===========
+*
+*       SUBROUTINE SDRVES( NSIZES, NN, NTYPES, DOTYPE, ISEED, THRESH,
+*                          NOUNIT, A, LDA, H, HT, WR, WI, WRT, WIT, VS,
+*                          LDVS, RESULT, WORK, NWORK, IWORK, BWORK, INFO )
+*
+*       .. Scalar Arguments ..
+*       INTEGER            INFO, LDA, LDVS, NOUNIT, NSIZES, NTYPES, NWORK
+*       REAL               THRESH
+*       ..
+*       .. Array Arguments ..
+*       LOGICAL            BWORK( * ), DOTYPE( * )
+*       INTEGER            ISEED( 4 ), IWORK( * ), NN( * )
+*       REAL               A( LDA, * ), H( LDA, * ), HT( LDA, * ),
+*      $                   RESULT( 13 ), VS( LDVS, * ), WI( * ), WIT( * ),
+*      $                   WORK( * ), WR( * ), WRT( * )
+*       ..
+*
+*
+*> \par Purpose:
+*  =============
+*>
+*> \verbatim
+*>
+*>    SDRVES checks the nonsymmetric eigenvalue (Schur form) problem
+*>    driver SGEES.
+*>
+*>    When SDRVES is called, a number of matrix "sizes" ("n's") and a
+*>    number of matrix "types" are specified.  For each size ("n")
+*>    and each type of matrix, one matrix will be generated and used
+*>    to test the nonsymmetric eigenroutines.  For each matrix, 13
+*>    tests will be performed:
+*>
+*>    (1)     0 if T is in Schur form, 1/ulp otherwise
+*>           (no sorting of eigenvalues)
+*>
+*>    (2)     | A - VS T VS' | / ( n |A| ulp )
+*>
+*>      Here VS is the matrix of Schur eigenvectors, and T is in Schur
+*>      form  (no sorting of eigenvalues).
+*>
+*>    (3)     | I - VS VS' | / ( n ulp ) (no sorting of eigenvalues).
+*>
+*>    (4)     0     if WR+sqrt(-1)*WI are eigenvalues of T
+*>            1/ulp otherwise
+*>            (no sorting of eigenvalues)
+*>
+*>    (5)     0     if T(with VS) = T(without VS),
+*>            1/ulp otherwise
+*>            (no sorting of eigenvalues)
+*>
+*>    (6)     0     if eigenvalues(with VS) = eigenvalues(without VS),
+*>            1/ulp otherwise
+*>            (no sorting of eigenvalues)
+*>
+*>    (7)     0 if T is in Schur form, 1/ulp otherwise
+*>            (with sorting of eigenvalues)
+*>
+*>    (8)     | A - VS T VS' | / ( n |A| ulp )
+*>
+*>      Here VS is the matrix of Schur eigenvectors, and T is in Schur
+*>      form  (with sorting of eigenvalues).
+*>
+*>    (9)     | I - VS VS' | / ( n ulp ) (with sorting of eigenvalues).
+*>
+*>    (10)    0     if WR+sqrt(-1)*WI are eigenvalues of T
+*>            1/ulp otherwise
+*>            (with sorting of eigenvalues)
+*>
+*>    (11)    0     if T(with VS) = T(without VS),
+*>            1/ulp otherwise
+*>            (with sorting of eigenvalues)
+*>
+*>    (12)    0     if eigenvalues(with VS) = eigenvalues(without VS),
+*>            1/ulp otherwise
+*>            (with sorting of eigenvalues)
+*>
+*>    (13)    if sorting worked and SDIM is the number of
+*>            eigenvalues which were SELECTed
+*>
+*>    The "sizes" are specified by an array NN(1:NSIZES); the value of
+*>    each element NN(j) specifies one size.
+*>    The "types" are specified by a logical array DOTYPE( 1:NTYPES );
+*>    if DOTYPE(j) is .TRUE., then matrix type "j" will be generated.
+*>    Currently, the list of possible types is:
+*>
+*>    (1)  The zero matrix.
+*>    (2)  The identity matrix.
+*>    (3)  A (transposed) Jordan block, with 1's on the diagonal.
+*>
+*>    (4)  A diagonal matrix with evenly spaced entries
+*>         1, ..., ULP  and random signs.
+*>         (ULP = (first number larger than 1) - 1 )
+*>    (5)  A diagonal matrix with geometrically spaced entries
+*>         1, ..., ULP  and random signs.
+*>    (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP
+*>         and random signs.
+*>
+*>    (7)  Same as (4), but multiplied by a constant near
+*>         the overflow threshold
+*>    (8)  Same as (4), but multiplied by a constant near
+*>         the underflow threshold
+*>
+*>    (9)  A matrix of the form  U' T U, where U is orthogonal and
+*>         T has evenly spaced entries 1, ..., ULP with random signs
+*>         on the diagonal and random O(1) entries in the upper
+*>         triangle.
+*>
+*>    (10) A matrix of the form  U' T U, where U is orthogonal and
+*>         T has geometrically spaced entries 1, ..., ULP with random
+*>         signs on the diagonal and random O(1) entries in the upper
+*>         triangle.
+*>
+*>    (11) A matrix of the form  U' T U, where U is orthogonal and
+*>         T has "clustered" entries 1, ULP,..., ULP with random
+*>         signs on the diagonal and random O(1) entries in the upper
+*>         triangle.
+*>
+*>    (12) A matrix of the form  U' T U, where U is orthogonal and
+*>         T has real or complex conjugate paired eigenvalues randomly
+*>         chosen from ( ULP, 1 ) and random O(1) entries in the upper
+*>         triangle.
+*>
+*>    (13) A matrix of the form  X' T X, where X has condition
+*>         SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP
+*>         with random signs on the diagonal and random O(1) entries
+*>         in the upper triangle.
+*>
+*>    (14) A matrix of the form  X' T X, where X has condition
+*>         SQRT( ULP ) and T has geometrically spaced entries
+*>         1, ..., ULP with random signs on the diagonal and random
+*>         O(1) entries in the upper triangle.
+*>
+*>    (15) A matrix of the form  X' T X, where X has condition
+*>         SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP
+*>         with random signs on the diagonal and random O(1) entries
+*>         in the upper triangle.
+*>
+*>    (16) A matrix of the form  X' T X, where X has condition
+*>         SQRT( ULP ) and T has real or complex conjugate paired
+*>         eigenvalues randomly chosen from ( ULP, 1 ) and random
+*>         O(1) entries in the upper triangle.
+*>
+*>    (17) Same as (16), but multiplied by a constant
+*>         near the overflow threshold
+*>    (18) Same as (16), but multiplied by a constant
+*>         near the underflow threshold
+*>
+*>    (19) Nonsymmetric matrix with random entries chosen from (-1,1).
+*>         If N is at least 4, all entries in first two rows and last
+*>         row, and first column and last two columns are zero.
+*>    (20) Same as (19), but multiplied by a constant
+*>         near the overflow threshold
+*>    (21) Same as (19), but multiplied by a constant
+*>         near the underflow threshold
+*> \endverbatim
+*
+*  Arguments:
+*  ==========
+*
+*> \param[in] NSIZES
+*> \verbatim
+*>          NSIZES is INTEGER
+*>          The number of sizes of matrices to use.  If it is zero,
+*>          SDRVES does nothing.  It must be at least zero.
+*> \endverbatim
+*>
+*> \param[in] NN
+*> \verbatim
+*>          NN is INTEGER array, dimension (NSIZES)
+*>          An array containing the sizes to be used for the matrices.
+*>          Zero values will be skipped.  The values must be at least
+*>          zero.
+*> \endverbatim
+*>
+*> \param[in] NTYPES
+*> \verbatim
+*>          NTYPES is INTEGER
+*>          The number of elements in DOTYPE.   If it is zero, SDRVES
+*>          does nothing.  It must be at least zero.  If it is MAXTYP+1
+*>          and NSIZES is 1, then an additional type, MAXTYP+1 is
+*>          defined, which is to use whatever matrix is in A.  This
+*>          is only useful if DOTYPE(1:MAXTYP) is .FALSE. and
+*>          DOTYPE(MAXTYP+1) is .TRUE. .
+*> \endverbatim
+*>
+*> \param[in] DOTYPE
+*> \verbatim
+*>          DOTYPE is LOGICAL array, dimension (NTYPES)
+*>          If DOTYPE(j) is .TRUE., then for each size in NN a
+*>          matrix of that size and of type j will be generated.
+*>          If NTYPES is smaller than the maximum number of types
+*>          defined (PARAMETER MAXTYP), then types NTYPES+1 through
+*>          MAXTYP will not be generated.  If NTYPES is larger
+*>          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)
+*>          will be ignored.
+*> \endverbatim
+*>
+*> \param[in,out] ISEED
+*> \verbatim
+*>          ISEED is INTEGER array, dimension (4)
+*>          On entry ISEED specifies the seed of the random number
+*>          generator. The array elements should be between 0 and 4095;
+*>          if not they will be reduced mod 4096.  Also, ISEED(4) must
+*>          be odd.  The random number generator uses a linear
+*>          congruential sequence limited to small integers, and so
+*>          should produce machine independent random numbers. The
+*>          values of ISEED are changed on exit, and can be used in the
+*>          next call to SDRVES to continue the same random number
+*>          sequence.
+*> \endverbatim
+*>
+*> \param[in] THRESH
+*> \verbatim
+*>          THRESH is REAL
+*>          A test will count as "failed" if the "error", computed as
+*>          described above, exceeds THRESH.  Note that the error
+*>          is scaled to be O(1), so THRESH should be a reasonably
+*>          small multiple of 1, e.g., 10 or 100.  In particular,
+*>          it should not depend on the precision (single vs. double)
+*>          or the size of the matrix.  It must be at least zero.
+*> \endverbatim
+*>
+*> \param[in] NOUNIT
+*> \verbatim
+*>          NOUNIT is INTEGER
+*>          The FORTRAN unit number for printing out error messages
+*>          (e.g., if a routine returns INFO not equal to 0.)
+*> \endverbatim
+*>
+*> \param[out] A
+*> \verbatim
+*>          A is REAL array, dimension (LDA, max(NN))
+*>          Used to hold the matrix whose eigenvalues are to be
+*>          computed.  On exit, A contains the last matrix actually used.
+*> \endverbatim
+*>
+*> \param[in] LDA
+*> \verbatim
+*>          LDA is INTEGER
+*>          The leading dimension of A, and H. LDA must be at
+*>          least 1 and at least max(NN).
+*> \endverbatim
+*>
+*> \param[out] H
+*> \verbatim
+*>          H is REAL array, dimension (LDA, max(NN))
+*>          Another copy of the test matrix A, modified by SGEES.
+*> \endverbatim
+*>
+*> \param[out] HT
+*> \verbatim
+*>          HT is REAL array, dimension (LDA, max(NN))
+*>          Yet another copy of the test matrix A, modified by SGEES.
+*> \endverbatim
+*>
+*> \param[out] WR
+*> \verbatim
+*>          WR is REAL array, dimension (max(NN))
+*> \endverbatim
+*>
+*> \param[out] WI
+*> \verbatim
+*>          WI is REAL array, dimension (max(NN))
+*>
+*>          The real and imaginary parts of the eigenvalues of A.
+*>          On exit, WR + WI*i are the eigenvalues of the matrix in A.
+*> \endverbatim
+*>
+*> \param[out] WRT
+*> \verbatim
+*>          WRT is REAL array, dimension (max(NN))
+*> \endverbatim
+*>
+*> \param[out] WIT
+*> \verbatim
+*>          WIT is REAL array, dimension (max(NN))
+*>
+*>          Like WR, WI, these arrays contain the eigenvalues of A,
+*>          but those computed when SGEES only computes a partial
+*>          eigendecomposition, i.e. not Schur vectors
+*> \endverbatim
+*>
+*> \param[out] VS
+*> \verbatim
+*>          VS is REAL array, dimension (LDVS, max(NN))
+*>          VS holds the computed Schur vectors.
+*> \endverbatim
+*>
+*> \param[in] LDVS
+*> \verbatim
+*>          LDVS is INTEGER
+*>          Leading dimension of VS. Must be at least max(1,max(NN)).
+*> \endverbatim
+*>
+*> \param[out] RESULT
+*> \verbatim
+*>          RESULT is REAL array, dimension (13)
+*>          The values computed by the 13 tests described above.
+*>          The values are currently limited to 1/ulp, to avoid overflow.
+*> \endverbatim
+*>
+*> \param[out] WORK
+*> \verbatim
+*>          WORK is REAL array, dimension (NWORK)
+*> \endverbatim
+*>
+*> \param[in] NWORK
+*> \verbatim
+*>          NWORK is INTEGER
+*>          The number of entries in WORK.  This must be at least
+*>          5*NN(j)+2*NN(j)**2 for all j.
+*> \endverbatim
+*>
+*> \param[out] IWORK
+*> \verbatim
+*>          IWORK is INTEGER array, dimension (max(NN))
+*> \endverbatim
+*>
+*> \param[out] BWORK
+*> \verbatim
+*>          BWORK is LOGICAL array, dimension (max(NN))
+*> \endverbatim
+*>
+*> \param[out] INFO
+*> \verbatim
+*>          INFO is INTEGER
+*>          If 0, then everything ran OK.
+*>           -1: NSIZES < 0
+*>           -2: Some NN(j) < 0
+*>           -3: NTYPES < 0
+*>           -6: THRESH < 0
+*>           -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ).
+*>          -17: LDVS < 1 or LDVS < NMAX, where NMAX is max( NN(j) ).
+*>          -20: NWORK too small.
+*>          If  SLATMR, SLATMS, SLATME or SGEES returns an error code,
+*>              the absolute value of it is returned.
+*>
+*>-----------------------------------------------------------------------
+*>
+*>     Some Local Variables and Parameters:
+*>     ---- ----- --------- --- ----------
+*>
+*>     ZERO, ONE       Real 0 and 1.
+*>     MAXTYP          The number of types defined.
+*>     NMAX            Largest value in NN.
+*>     NERRS           The number of tests which have exceeded THRESH
+*>     COND, CONDS,
+*>     IMODE           Values to be passed to the matrix generators.
+*>     ANORM           Norm of A; passed to matrix generators.
+*>
+*>     OVFL, UNFL      Overflow and underflow thresholds.
+*>     ULP, ULPINV     Finest relative precision and its inverse.
+*>     RTULP, RTULPI   Square roots of the previous 4 values.
+*>
+*>             The following four arrays decode JTYPE:
+*>     KTYPE(j)        The general type (1-10) for type "j".
+*>     KMODE(j)        The MODE value to be passed to the matrix
+*>                     generator for type "j".
+*>     KMAGN(j)        The order of magnitude ( O(1),
+*>                     O(overflow^(1/2) ), O(underflow^(1/2) )
+*>     KCONDS(j)       Selectw whether CONDS is to be 1 or
+*>                     1/sqrt(ulp).  (0 means irrelevant.)
+*> \endverbatim
+*
+*  Authors:
+*  ========
+*
+*> \author Univ. of Tennessee
+*> \author Univ. of California Berkeley
+*> \author Univ. of Colorado Denver
+*> \author NAG Ltd.
+*
+*> \ingroup single_eig
+*
+*  =====================================================================
       SUBROUTINE SDRVES( NSIZES, NN, NTYPES, DOTYPE, ISEED, THRESH,
      $                   NOUNIT, A, LDA, H, HT, WR, WI, WRT, WIT, VS,
      $                   LDVS, RESULT, WORK, NWORK, IWORK, BWORK, INFO )
 *
-*  -- LAPACK test routine (version 2.0) --
-*     Univ. of Tennessee, Univ. of California Berkeley, NAG Ltd.,
-*     Courant Institute, Argonne National Lab, and Rice University
-*     September 30, 1994
+*  -- LAPACK test routine --
+*  -- LAPACK is a software package provided by Univ. of Tennessee,    --
+*  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDVS, NOUNIT, NSIZES, NTYPES, NWORK
@@ -19,274 +402,6 @@
      $                   WORK( * ), WR( * ), WRT( * )
 *     ..
 *
-*  Purpose
-*  =======
-*
-*     SDRVES checks the nonsymmetric eigenvalue (Schur form) problem
-*     driver SGEES.
-*
-*     When SDRVES is called, a number of matrix "sizes" ("n's") and a
-*     number of matrix "types" are specified.  For each size ("n")
-*     and each type of matrix, one matrix will be generated and used
-*     to test the nonsymmetric eigenroutines.  For each matrix, 13
-*     tests will be performed:
-*
-*     (1)     0 if T is in Schur form, 1/ulp otherwise
-*            (no sorting of eigenvalues)
-*
-*     (2)     | A - VS T VS' | / ( n |A| ulp )
-*
-*       Here VS is the matrix of Schur eigenvectors, and T is in Schur
-*       form  (no sorting of eigenvalues).
-*
-*     (3)     | I - VS VS' | / ( n ulp ) (no sorting of eigenvalues).
-*
-*     (4)     0     if WR+sqrt(-1)*WI are eigenvalues of T
-*             1/ulp otherwise
-*             (no sorting of eigenvalues)
-*
-*     (5)     0     if T(with VS) = T(without VS),
-*             1/ulp otherwise
-*             (no sorting of eigenvalues)
-*
-*     (6)     0     if eigenvalues(with VS) = eigenvalues(without VS),
-*             1/ulp otherwise
-*             (no sorting of eigenvalues)
-*
-*     (7)     0 if T is in Schur form, 1/ulp otherwise
-*             (with sorting of eigenvalues)
-*
-*     (8)     | A - VS T VS' | / ( n |A| ulp )
-*
-*       Here VS is the matrix of Schur eigenvectors, and T is in Schur
-*       form  (with sorting of eigenvalues).
-*
-*     (9)     | I - VS VS' | / ( n ulp ) (with sorting of eigenvalues).
-*
-*     (10)    0     if WR+sqrt(-1)*WI are eigenvalues of T
-*             1/ulp otherwise
-*             (with sorting of eigenvalues)
-*
-*     (11)    0     if T(with VS) = T(without VS),
-*             1/ulp otherwise
-*             (with sorting of eigenvalues)
-*
-*     (12)    0     if eigenvalues(with VS) = eigenvalues(without VS),
-*             1/ulp otherwise
-*             (with sorting of eigenvalues)
-*
-*     (13)    if sorting worked and SDIM is the number of
-*             eigenvalues which were SELECTed
-*
-*     The "sizes" are specified by an array NN(1:NSIZES); the value of
-*     each element NN(j) specifies one size.
-*     The "types" are specified by a logical array DOTYPE( 1:NTYPES );
-*     if DOTYPE(j) is .TRUE., then matrix type "j" will be generated.
-*     Currently, the list of possible types is:
-*
-*     (1)  The zero matrix.
-*     (2)  The identity matrix.
-*     (3)  A (transposed) Jordan block, with 1's on the diagonal.
-*
-*     (4)  A diagonal matrix with evenly spaced entries
-*          1, ..., ULP  and random signs.
-*          (ULP = (first number larger than 1) - 1 )
-*     (5)  A diagonal matrix with geometrically spaced entries
-*          1, ..., ULP  and random signs.
-*     (6)  A diagonal matrix with "clustered" entries 1, ULP, ..., ULP
-*          and random signs.
-*
-*     (7)  Same as (4), but multiplied by a constant near
-*          the overflow threshold
-*     (8)  Same as (4), but multiplied by a constant near
-*          the underflow threshold
-*
-*     (9)  A matrix of the form  U' T U, where U is orthogonal and
-*          T has evenly spaced entries 1, ..., ULP with random signs
-*          on the diagonal and random O(1) entries in the upper
-*          triangle.
-*
-*     (10) A matrix of the form  U' T U, where U is orthogonal and
-*          T has geometrically spaced entries 1, ..., ULP with random
-*          signs on the diagonal and random O(1) entries in the upper
-*          triangle.
-*
-*     (11) A matrix of the form  U' T U, where U is orthogonal and
-*          T has "clustered" entries 1, ULP,..., ULP with random
-*          signs on the diagonal and random O(1) entries in the upper
-*          triangle.
-*
-*     (12) A matrix of the form  U' T U, where U is orthogonal and
-*          T has real or complex conjugate paired eigenvalues randomly
-*          chosen from ( ULP, 1 ) and random O(1) entries in the upper
-*          triangle.
-*
-*     (13) A matrix of the form  X' T X, where X has condition
-*          SQRT( ULP ) and T has evenly spaced entries 1, ..., ULP
-*          with random signs on the diagonal and random O(1) entries
-*          in the upper triangle.
-*
-*     (14) A matrix of the form  X' T X, where X has condition
-*          SQRT( ULP ) and T has geometrically spaced entries
-*          1, ..., ULP with random signs on the diagonal and random
-*          O(1) entries in the upper triangle.
-*
-*     (15) A matrix of the form  X' T X, where X has condition
-*          SQRT( ULP ) and T has "clustered" entries 1, ULP,..., ULP
-*          with random signs on the diagonal and random O(1) entries
-*          in the upper triangle.
-*
-*     (16) A matrix of the form  X' T X, where X has condition
-*          SQRT( ULP ) and T has real or complex conjugate paired
-*          eigenvalues randomly chosen from ( ULP, 1 ) and random
-*          O(1) entries in the upper triangle.
-*
-*     (17) Same as (16), but multiplied by a constant
-*          near the overflow threshold
-*     (18) Same as (16), but multiplied by a constant
-*          near the underflow threshold
-*
-*     (19) Nonsymmetric matrix with random entries chosen from (-1,1).
-*          If N is at least 4, all entries in first two rows and last
-*          row, and first column and last two columns are zero.
-*     (20) Same as (19), but multiplied by a constant
-*          near the overflow threshold
-*     (21) Same as (19), but multiplied by a constant
-*          near the underflow threshold
-*
-*  Arguments
-*  =========
-*
-*  NSIZES  (input) INTEGER
-*          The number of sizes of matrices to use.  If it is zero,
-*          SDRVES does nothing.  It must be at least zero.
-*
-*  NN      (input) INTEGER array, dimension (NSIZES)
-*          An array containing the sizes to be used for the matrices.
-*          Zero values will be skipped.  The values must be at least
-*          zero.
-*
-*  NTYPES  (input) INTEGER
-*          The number of elements in DOTYPE.   If it is zero, SDRVES
-*          does nothing.  It must be at least zero.  If it is MAXTYP+1
-*          and NSIZES is 1, then an additional type, MAXTYP+1 is
-*          defined, which is to use whatever matrix is in A.  This
-*          is only useful if DOTYPE(1:MAXTYP) is .FALSE. and
-*          DOTYPE(MAXTYP+1) is .TRUE. .
-*
-*  DOTYPE  (input) LOGICAL array, dimension (NTYPES)
-*          If DOTYPE(j) is .TRUE., then for each size in NN a
-*          matrix of that size and of type j will be generated.
-*          If NTYPES is smaller than the maximum number of types
-*          defined (PARAMETER MAXTYP), then types NTYPES+1 through
-*          MAXTYP will not be generated.  If NTYPES is larger
-*          than MAXTYP, DOTYPE(MAXTYP+1) through DOTYPE(NTYPES)
-*          will be ignored.
-*
-*  ISEED   (input/output) INTEGER array, dimension (4)
-*          On entry ISEED specifies the seed of the random number
-*          generator. The array elements should be between 0 and 4095;
-*          if not they will be reduced mod 4096.  Also, ISEED(4) must
-*          be odd.  The random number generator uses a linear
-*          congruential sequence limited to small integers, and so
-*          should produce machine independent random numbers. The
-*          values of ISEED are changed on exit, and can be used in the
-*          next call to SDRVES to continue the same random number
-*          sequence.
-*
-*  THRESH  (input) REAL
-*          A test will count as "failed" if the "error", computed as
-*          described above, exceeds THRESH.  Note that the error
-*          is scaled to be O(1), so THRESH should be a reasonably
-*          small multiple of 1, e.g., 10 or 100.  In particular,
-*          it should not depend on the precision (single vs. double)
-*          or the size of the matrix.  It must be at least zero.
-*
-*  NOUNIT  (input) INTEGER
-*          The FORTRAN unit number for printing out error messages
-*          (e.g., if a routine returns INFO not equal to 0.)
-*
-*  A       (workspace) REAL array, dimension (LDA, max(NN))
-*          Used to hold the matrix whose eigenvalues are to be
-*          computed.  On exit, A contains the last matrix actually used.
-*
-*  LDA     (input) INTEGER
-*          The leading dimension of A, and H. LDA must be at
-*          least 1 and at least max(NN).
-*
-*  H       (workspace) REAL array, dimension (LDA, max(NN))
-*          Another copy of the test matrix A, modified by SGEES.
-*
-*  HT      (workspace) REAL array, dimension (LDA, max(NN))
-*          Yet another copy of the test matrix A, modified by SGEES.
-*
-*  WR      (workspace) REAL array, dimension (max(NN))
-*  WI      (workspace) REAL array, dimension (max(NN))
-*          The real and imaginary parts of the eigenvalues of A.
-*          On exit, WR + WI*i are the eigenvalues of the matrix in A.
-*
-*  WRT     (workspace) REAL array, dimension (max(NN))
-*  WIT     (workspace) REAL array, dimension (max(NN))
-*          Like WR, WI, these arrays contain the eigenvalues of A,
-*          but those computed when SGEES only computes a partial
-*          eigendecomposition, i.e. not Schur vectors
-*
-*  VS      (workspace) REAL array, dimension (LDVS, max(NN))
-*          VS holds the computed Schur vectors.
-*
-*  LDVS    (input) INTEGER
-*          Leading dimension of VS. Must be at least max(1,max(NN)).
-*
-*  RESULT  (output) REAL array, dimension (13)
-*          The values computed by the 13 tests described above.
-*          The values are currently limited to 1/ulp, to avoid overflow.
-*
-*  WORK    (workspace) REAL array, dimension (NWORK)
-*
-*  NWORK   (input) INTEGER
-*          The number of entries in WORK.  This must be at least
-*          5*NN(j)+2*NN(j)**2 for all j.
-*
-*  IWORK   (workspace) INTEGER array, dimension (max(NN))
-*
-*  INFO    (output) INTEGER
-*          If 0, then everything ran OK.
-*           -1: NSIZES < 0
-*           -2: Some NN(j) < 0
-*           -3: NTYPES < 0
-*           -6: THRESH < 0
-*           -9: LDA < 1 or LDA < NMAX, where NMAX is max( NN(j) ).
-*          -17: LDVS < 1 or LDVS < NMAX, where NMAX is max( NN(j) ).
-*          -20: NWORK too small.
-*          If  SLATMR, SLATMS, SLATME or SGEES returns an error code,
-*              the absolute value of it is returned.
-*
-*-----------------------------------------------------------------------
-*
-*     Some Local Variables and Parameters:
-*     ---- ----- --------- --- ----------
-*
-*     ZERO, ONE       Real 0 and 1.
-*     MAXTYP          The number of types defined.
-*     NMAX            Largest value in NN.
-*     NERRS           The number of tests which have exceeded THRESH
-*     COND, CONDS,
-*     IMODE           Values to be passed to the matrix generators.
-*     ANORM           Norm of A; passed to matrix generators.
-*
-*     OVFL, UNFL      Overflow and underflow thresholds.
-*     ULP, ULPINV     Finest relative precision and its inverse.
-*     RTULP, RTULPI   Square roots of the previous 4 values.
-*
-*             The following four arrays decode JTYPE:
-*     KTYPE(j)        The general type (1-10) for type "j".
-*     KMODE(j)        The MODE value to be passed to the matrix
-*                     generator for type "j".
-*     KMAGN(j)        The order of magnitude ( O(1),
-*                     O(overflow^(1/2) ), O(underflow^(1/2) )
-*     KCONDS(j)       Selectw whether CONDS is to be 1 or
-*                     1/sqrt(ulp).  (0 means irrelevant.)
-*
 *  =====================================================================
 *
 *     .. Parameters ..
@@ -329,8 +444,8 @@
       EXTERNAL           SSLECT, SLAMCH
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           SGEES, SHST01, SLABAD, SLACPY, SLASUM, SLATME,
-     $                   SLATMR, SLATMS, SLASET, XERBLA
+      EXTERNAL           SGEES, SHST01, SLACPY, SLASUM, SLATME, SLATMR,
+     $                   SLATMS, SLASET, XERBLA
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, MAX, SIGN, SQRT
@@ -345,7 +460,7 @@
 *     ..
 *     .. Executable Statements ..
 *
-      PATH( 1: 1 ) = 'S'
+      PATH( 1: 1 ) = 'Single precision'
       PATH( 2: 3 ) = 'ES'
 *
 *     Check for errors
@@ -399,7 +514,6 @@
 *
       UNFL = SLAMCH( 'Safe minimum' )
       OVFL = ONE / UNFL
-      CALL SLABAD( UNFL, OVFL )
       ULP = SLAMCH( 'Precision' )
       ULPINV = ONE / ULP
       RTULP = SQRT( ULP )
@@ -830,7 +944,7 @@
      $      '  1/ulp otherwise', /
      $      ' 12 = 0 if WR, WI same no matter if VS computed (sort),',
      $      '  1/ulp otherwise', /
-     $      ' 13 = 0 if sorting succesful, 1/ulp otherwise', / )
+     $      ' 13 = 0 if sorting successful, 1/ulp otherwise', / )
  9993 FORMAT( ' N=', I5, ', IWK=', I2, ', seed=', 4( I4, ',' ),
      $      ' type ', I2, ', test(', I2, ')=', G10.3 )
  9992 FORMAT( ' SDRVES: ', A, ' returned INFO=', I6, '.', / 9X, 'N=',
