@@ -50,7 +50,7 @@
 *> number of matrix "TYPES" are specified.  For each size ("N")
 *> and each TYPE of matrix, a pair of matrices (A, B) will be generated
 *> and used for testing. For each matrix pair, the following 13 tests
-*> will be performed and compared with the threshhold THRESH except
+*> will be performed and compared with the threshold THRESH except
 *> the tests (5), (11) and (13).
 *>
 *>
@@ -372,8 +372,6 @@
 *> \author Univ. of Colorado Denver
 *> \author NAG Ltd.
 *
-*> \date February 2015
-*
 *> \ingroup complex16_eig
 *
 *  =====================================================================
@@ -382,10 +380,9 @@
      $                    BETA, WORK, LWORK, RWORK, RESULT, BWORK,
      $                    INFO )
 *
-*  -- LAPACK test routine (version 3.6.0) --
+*  -- LAPACK test routine --
 *  -- LAPACK is a software package provided by Univ. of Tennessee,    --
 *  -- Univ. of California Berkeley, Univ. of Colorado Denver and NAG Ltd..--
-*     February 2015
 *
 *     .. Scalar Arguments ..
       INTEGER            INFO, LDA, LDQ, LWORK, NOUNIT, NSIZES, NTYPES
@@ -438,8 +435,8 @@
       EXTERNAL           ZLCTES, ILAENV, DLAMCH, ZLARND
 *     ..
 *     .. External Subroutines ..
-      EXTERNAL           ALASVM, DLABAD, XERBLA, ZGET51, ZGET54, ZGGES3,
-     $                   ZLACPY, ZLARFG, ZLASET, ZLATM4, ZUNM2R
+      EXTERNAL           ALASVM, XERBLA, ZGET51, ZGET54, ZGGES3, ZLACPY,
+     $                   ZLARFG, ZLASET, ZLATM4, ZUNM2R
 *     ..
 *     .. Intrinsic Functions ..
       INTRINSIC          ABS, DBLE, DCONJG, DIMAG, MAX, MIN, SIGN
@@ -537,7 +534,6 @@
       SAFMIN = DLAMCH( 'Safe minimum' )
       SAFMIN = SAFMIN / ULP
       SAFMAX = ONE / SAFMIN
-      CALL DLABAD( SAFMIN, SAFMAX )
       ULPINV = ONE / ULP
 *
 *     The values RMAGN(2:3) depend on N, see below.
@@ -744,6 +740,14 @@
                   RSUB = 5
                END IF
 *
+*              Call XLAENV to set the parameters used in ZLAQZ0
+*
+               CALL XLAENV( 12, 10 )
+               CALL XLAENV( 13, 12 )
+               CALL XLAENV( 14, 13 )
+               CALL XLAENV( 15, 2 )
+               CALL XLAENV( 17, 10 )
+*
 *              Call ZGGES3 to compute H, T, Q, Z, alpha, and beta.
 *
                CALL ZLACPY( 'Full', N, N, A, LDA, S, LDA )
